##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################
#----------------------------------------------------------------------------------
#  
#       Name: DataSource.py
#
#	This script creates or removes a Data Source necessary for Cloudburst
#
#       Parameters:
#               option           - 'create' or 'remove'
#               cellName         - default: ctgCell01
#               nodeName         - default: ctgNode01
#               serverName       - default: MXServer
#		db2server	 - default: localhost
#		db2port		 - default: 50005
#	Return values:
#		0 - Successfully executed
#		1 - Fail to execute
#		2 - No valid arguments
#----------------------------------------------------------------------------------

#----------------------------------------------------------------------------------
# 	Usage
#----------------------------------------------------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f DataSource.py <create | remove> [cellName] [nodeName] [serverName] [db2port] where"
    print "	   <create | remove>	specifies which action should be performed"
    print "        [cellName]    	is the name of cell in which data source is created/removed (required for create and remove)"
    print "        [nodeName]    	is the name of node in which the data source is created/removed (required for create and remove)"
    print "        [serverName]    	is the name of server in which the data source is created/removed (required for create and remove)"
    print "        [db2server]          is the name of server where db2 is running at (required for create and remove)"
    print "        [db2port]            is the portnumber which is used by the maximo db2 user (required for create and remove)"

#----------------------------------------------------------------------------------
# 	checks whether the jdbc provider exists
#	Return:
#		true - if exists
#		false - if not 
#----------------------------------------------------------------------------------
def jdbcProviderExist(cellName,nodeName,serverName):
	jdbcProvider = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/Server:"+serverName+"/JDBCProvider:DB2 Universal JDBC Driver Provider/" )

	if not (len(jdbcProvider) == 0):
		return 'true'
		
	return 'false'

#----------------------------------------------------------------------------------
# 	checks whether the data source exists
#	Return:
#		true - if exists
#		false - if not 
#----------------------------------------------------------------------------------
def dataSourceExist(cellName,nodeName,serverName):
	dataSource = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/Server:"+serverName+"/JDBCProvider:DB2 Universal JDBC Driver Provider/DataSource:TPM71/" )

	if not (len(dataSource) == 0):
		return 'true'
		
	return 'false'

#----------------------------------------------------------------------------------
# 	removes data source
#		cellName - the name of the cell in which the data source is created
#		nodeName - the name of the node in which the data source is created
#		serverName - the name of the server in which the data source is created
#----------------------------------------------------------------------------------
def remove(cellName,nodeName,serverName):
	dataSource = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/Server:"+serverName+"/JDBCProvider:DB2 Universal JDBC Driver Provider/DataSource:TPM71/" )

	AdminConfig.remove(dataSource)
	AdminConfig.save()

#----------------------------------------------------------------------------------
# 	creates data source
#		cellName - the name of the cell in which the data source is created
#		nodeName - the name of the node in which the data source is created
#		serverName - the name of the server in which the data source is created
#----------------------------------------------------------------------------------
def create(cellName,nodeName,serverName,db2serverName,portNumber,dbName):
	# Get the ID of the JDBC Provider where the datasource will be created in
	jdbcProvider = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/Server:"+serverName+"/JDBCProvider:DB2 Universal JDBC Driver Provider/" )
	
	AdminTask.createDatasource(jdbcProvider, '[-name TPM71 -jndiName jdbc/tcDB -dataStoreHelperClassName com.ibm.websphere.rsadapter.DB2UniversalDataStoreHelper -componentManagedAuthenticationAlias CDSDataAuth -configureResourceProperties [[databaseName java.lang.String '+dbName+'] [driverType java.lang.Integer 4] [serverName java.lang.String '+db2serverName+'] [portNumber java.lang.Integer '+portNumber+']]]') 	
	# Get the ID of the new created datasource and create a connection pool for it
	dataSource = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/Server:"+serverName+"/JDBCProvider:DB2 Universal JDBC Driver Provider/DataSource:TPM71/" )

	AdminConfig.create("ConnectionPool", dataSource, [["maxConnections", 30], ["minConnections", 5]])

	AdminConfig.save()

		
	
#----------------------------------------------------------------------------------	
# 	main
#----------------------------------------------------------------------------------
if (len(sys.argv) == 7):

	flag = sys.argv[0]
	cellName = sys.argv[1]
	nodeName = sys.argv[2]
	serverName = sys.argv[3]
	db2serverName = sys.argv[4]
	portNumber = sys.argv[5]
	dbName = sys.argv[6]
	
	if not (flag == 'create') and not (flag == 'remove') :
		sys.stderr.write('First argument not valid\n')
		printUsage()
		sys.exit(2)
	if (flag == 'remove'):
		if (jdbcProviderExist(cellName,nodeName,serverName) == 'true'):
			if (dataSourceExist(cellName,nodeName,serverName) == 'true'):
				remove(cellName,nodeName,serverName)
				sys.stdout.write('Data Source removed\n')
				sys.exit(0)
			else: 
				sys.stderr.write('JDBC Provider does not exist\n')
				sys.exit(1)
		else: 
			sys.stderr.write('JDBC Provider dose not exist\n')
			sys.exit(1)
	if (flag == 'create'):
		if (jdbcProviderExist(cellName,nodeName,serverName) == 'true'):
			if (dataSourceExist(cellName,nodeName,serverName) == 'true'):			
				sys.stdout.write('Data Source already exist\n')
				sys.exit(0)

			create(cellName,nodeName,serverName,db2serverName,portNumber,dbName)
		
			if (dataSourceExist(cellName,nodeName,serverName) == 'false'):			
				sys.stderr.write('Data Source could not be created\n')
				sys.exit(1)

			sys.stdout.write('Data Source created\n')
			sys.exit(0)
		else:
			sys.stderr.write('Data Source already exist\n')
			sys.exit(1)
else:
	sys.stderr.write('No valid number of arguments\n')
	printUsage()
	sys.exit(2)
