##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################
#----------------------------------------------------------------------------------
#  
#       Name: JDBCProvider.py
#
#	This script creates or removes a JDBC provider necessary for Cloudburst
#
#       Parameters:
#               option           - 'create' or 'remove'
#               cellName         - default: ctgCell01
#               nodeName         - default: ctgNode01
#               serverName       - default: MXServer
#               applicationName  - default: MAXIMO
#	Return values:
#		0 - Successfully executed
#		1 - Fail to execute
#		2 - Not valid arguments
#----------------------------------------------------------------------------------

#----------------------------------------------------------------------------------
# 	Usage
#----------------------------------------------------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f JDBCProvider.py <create | remove> [cellName] [nodeName] [serverName] where"
    print "	   <create | remove>	specifies which action should be performed"
    print "        [cellName]    	is the name of cell in which jdbc provider is created/removed (required for create and remove)"
    print "        [nodeName]    	is the name of node in which the jdbc provider is created/removed (required for create and remove)"
    print "        [serverName]    	is the name of server in which the jdbc provider is created/removed (required for create and remove)"
    
#----------------------------------------------------------------------------------
# 	checks whether the jdbc provider exists
#	Return:
#		true - if exists
#		false - if not 
#----------------------------------------------------------------------------------
def jdbcProviderExist(cellName,nodeName,serverName):
	jdbcProvider = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/Server:"+serverName+"/JDBCProvider:DB2 Universal JDBC Driver Provider/" )

	if not (len(jdbcProvider) == 0):
		return 'true'
		
	return 'false'

#----------------------------------------------------------------------------------
# 	removes jdbc provider
#		cellName - the name of the cell in which the jdbc provider is created
#		nodeName - the name of the node in which the jdbc provider is created
#		serverName - the name of the server in which the jdbc provider is created
#----------------------------------------------------------------------------------
def remove(cellName,nodeName,serverName):
	jdbcProvider = AdminConfig.getid("/Node:"+nodeName+"/Server:"+serverName+"/JDBCProvider:DB2 Universal JDBC Driver Provider/" )

	AdminConfig.remove(jdbcProvider)
	AdminConfig.save()

#----------------------------------------------------------------------------------
# 	creates jdbc provider
#		cellName - the name of the cell in which the jdbc provider is created
#		nodeName - the name of the node in which the jdbc provider is created
#		serverName - the name of the server in which the jdbc provider is created
#----------------------------------------------------------------------------------
def create(cellName,nodeName,serverName):
	AdminTask.createJDBCProvider('[-scope Cell=' + cellName + ',Node=' + nodeName + ',Server=' + serverName+ ' -databaseType DB2 -providerType "DB2 Universal JDBC Driver Provider" -implementationType "Connection pool data source" -name "DB2 Universal JDBC Driver Provider" -description "Non-XA DB2 Universal JDBC Driver-compliant Provider. Datasources created under this provider support only 1-phase commit processing except in the case where driver type 2 is used under WebSphere Application Server for Z/OS. On WebSphere Application Server for Z/OS, driver type 2 uses RRS and supports 2-phase commit processing" -classpath ${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc.jar;${UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cu.jar;${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cisuz.jar -nativePath ${DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH} ]') 	
	AdminConfig.save()
	
#----------------------------------------------------------------------------------	
# 	main
#----------------------------------------------------------------------------------
if (len(sys.argv) == 4):

	flag = sys.argv[0]
	cellName = sys.argv[1]
	nodeName = sys.argv[2]
	serverName = sys.argv[3]
	
	if not (flag == 'create') and not (flag == 'remove') :
		sys.stderr.write('First argument not valid\n')
		printUsage()
		sys.exit(2)
	if (flag == 'remove'):
		if (jdbcProviderExist(cellName,nodeName,serverName) == 'true'):
			remove(cellName,nodeName,serverName)
			sys.stdout.write('JDBC provider removed\n')
			sys.exit(0)
		else: 
			sys.stdout.write('JDBC provider does not exist\n')
			sys.exit(0)
	if (flag == 'create'):
		if (jdbcProviderExist(cellName,nodeName,serverName) == 'false'):
			create(cellName,nodeName,serverName)
		
			if (jdbcProviderExist(cellName,nodeName,serverName) == 'false'):			
				sys.stderr.write('JDBC provider could not be created\n')
				sys.exit(1)

			sys.stdout.write('JDBC provider created\n')
			sys.exit(0)
		else:
			sys.stdout.write('JDBC provider already exist\n')
			sys.exit(0)
else:
	sys.stderr.write('No valid number of arguments\n')
	printUsage()
	sys.exit(2)
