##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################
#----------------------------------------------------------------------------------
#  
#       Name: TimerManager.py
# 
#	This script creates or removes a TimerManager 'tm/bcTimerManager' 
#       necessary for Cloudburst
#
#       Parameters:
#               option           - 'create' or 'remove'
#               cellName         - default: ctgCell01
#               nodeName         - default: ctgNode01
#               serverName       - default: MXServer
#	Return values:
#		0 - Successfully executed
#		1 - Fail to execute
#		2 - Not valid arguments
#----------------------------------------------------------------------------------

# get line separator 
import  java
lineSeparator = java.lang.System.getProperty('line.separator')


#----------------------------------------------------------------------------------
# 	Usage
#----------------------------------------------------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f TimerManager.py <create | remove> [cellName] [nodeName] [serverName] where"
    print "	   <create | remove>	specifies which action should be performed"
    print "        [cellName]    	is the name of cell in which the timer manager is created (required for create)"
    print "        [nodeName]    	is the name of node in which the timer manager is created (required for create)"
    print "        [serverName]    	is the name of server in which the timer manager is created (required for create)"
    
#----------------------------------------------------------------------------------
# 	checks whether the timer manager already exists
#	Return:
#		true - if exists
#		false - if not 
#----------------------------------------------------------------------------------
def timerManagerExist():
	timeMgrs = AdminConfig.list('TimerManagerProvider').split(lineSeparator)
	for timeMgr in timeMgrs:	
		mgrInfos = AdminConfig.list('TimerManagerInfo', timeMgr).split(lineSeparator)
		for mgrInfo in mgrInfos:
			if (AdminConfig.showAttribute(mgrInfo, 'jndiName') == 'tm/bcTimerManager'):
				return 'true'
	return 'false'

#----------------------------------------------------------------------------------
# 	removes timer manager 
#----------------------------------------------------------------------------------
def remove():
	timeMgrs = AdminConfig.list('TimerManagerProvider').split(lineSeparator)
	for timeMgr in timeMgrs:
		mgrInfos = AdminConfig.list('TimerManagerInfo', timeMgr).split(lineSeparator)
		for mgrInfo in mgrInfos:
			if (AdminConfig.showAttribute(mgrInfo, 'jndiName') == 'tm/bcTimerManager'):
				AdminConfig.remove(mgrInfo)
	AdminConfig.save()

#----------------------------------------------------------------------------------
# 	creates timer manager
#		cellName - the name of the cell in which the timer manager is created
#		nodeName - the name of the node in which the timer manager is created
#		serverName - the name of the server in which the timer manager is created
#----------------------------------------------------------------------------------
def create(cellName,nodeName,serverName):
	AdminConfig.create('TimerManagerInfo', '(cells/' + cellName + '/nodes/' + nodeName + '/servers/' + serverName + '|resources-pme.xml#TimerManagerProvider_1)', [['name', 'TPM71TimerManager'], ['jndiName', 'tm/bcTimerManager'], ['numAlarmThreads', '20'], ['serviceNames', 'security']])
	AdminConfig.save()
	
	
#----------------------------------------------------------------------------------	
# 	main
#----------------------------------------------------------------------------------

if (len(sys.argv) == 1):
	flag = sys.argv[0]
	if not (flag == 'remove'):
		sys.stderr.write('First argument not valid\n')
		printUsage()
		sys.exit(2)
	if (timerManagerExist() == 'true'):
		remove()
		sys.exit(0)
		if (timerManagerExist() == 'true'):
			sys.stderr.write('Timer Manager could not be removed\n')
			sys.exit(1)
		else: 
			sys.stdout.write('Timer Manager removed\n')
			sys.exit(0)
	else: 
		sys.stdout.write('Timer Manager does not exist\n')
		sys.exit(0)
elif (len(sys.argv) == 4):
	flag = sys.argv[0]
	if not (flag == 'create'):
		sys.stderr.write('Provided argument not valid\n')
		printUsage()
		sys.exit(2)		
	if (timerManagerExist() == 'false'):
		create(sys.argv[1],sys.argv[2],sys.argv[3])
		if (timerManagerExist() == 'false'):			
			sys.stderr.write('Timer Manager could not be created\n')
			sys.exit(1)
		else: 
			sys.stdout.write('Timer Manager created\n')
			sys.exit(0)
	else:
		sys.stdout.write('Timer Manager already exist\n')
		sys.exit(0)
else:
	sys.stderr.write('No valid number of arguments\n')
	printUsage()
	sys.exit(2)
