##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################
#----------------------------------------------------------------------------------
#  
#       Name: WASGlobalVariable.py
#
#	This script creates or removes a WAS globale variable.
#
#       Parameters:
#               option           - 'create' or 'remove'
#               variablename     - the name of the variable to be created or removed
#               value            - the value of the new variable
#               cellName         - default: ctgCell01
#               nodeName         - default: ctgNode01
#               serverName       - default: MXServer
#	Return values:
#		0 - Successfully executed
#		1 - Fail to execute
#		2 - Not valid arguments
#----------------------------------------------------------------------------------

#----------------------------------------------------------------------------------
# 	Usage
#----------------------------------------------------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f WASGlobalVariable.py <create | remove> [variable] [value] [cellName] [nodeName] [serverName] where"
    print "	   <create | remove>	specifies which action should be performed"
    print "        [variable]    	is the name of variable which should be created/removed (required for create and remove)"
    print "        [value]    		related (only required for create)"
    print "        [cellName]    	is the name of cell in which the variable should be created/removed (required for create and remove)"
    print "        [nodeName]    	is the name of node in which the variable should be created/removed (only required if cell/node scope)"
    print "        [serverName]    	is the name of server in which the variable should be created/removed (only required if cell/node/server scope)"
    

#----------------------------------------------------------------------------------
# 	removes a global variable
#		cellName - the name of the cell in which the variabel is created
#		nodeName - the name of the node in which the variabel is created
#		serverName - the name of the server in which the variabel is created
#----------------------------------------------------------------------------------
def remove(cellName,nodeName,serverName,variableName):
	if not (len(nodeName) == 0) and not (len(serverName) == 0) and not (len(variableName) == 0):
		AdminTask.removeVariable(['-variableName', variableName, '-scope Cell=' + cellName + ',Node=' + nodeName + ',Server=' + serverName])
		AdminConfig.save()

	elif not (len(nodeName) == 0) and (len(serverName) == 0) and not (len(variableName) == 0):
		AdminTask.removeVariable(['-variableName', variableName, '-scope Cell=' + cellName + ',Node=' + nodeName])
		AdminConfig.save()

	elif (len(nodeName) == 0) and (len(serverName) == 0) and not (len(variableName) == 0):
		AdminTask.removeVariable(['-variableName', variableName, '-scope Cell=' + cellName])
		AdminConfig.save()

#----------------------------------------------------------------------------------
# 	creates a global variable
#		cellName - the name of the cell in which the variabel is created
#		nodeName - the name of the node in which the variabel is created
#		serverName - the name of the server in which the variabel is created
#----------------------------------------------------------------------------------
def create(cellName,nodeName,serverName,variableName,variableValue):
	if not (len(nodeName) == 0) and not (len(serverName) == 0) and not (len(variableName) == 0):
		AdminTask.setVariable(['-variableName', variableName, '-variableValue', variableValue, '-scope Cell=' + cellName + ',Node=' + nodeName + ',Server=' + serverName])
		AdminConfig.save()

	elif not (len(nodeName) == 0) and (len(serverName) == 0) and not (len(variableName) == 0):
		AdminTask.setVariable(['-variableName', variableName, '-variableValue', variableValue, '-scope Cell=' + cellName + ',Node=' + nodeName])
		AdminConfig.save()

	elif (len(nodeName) == 0) and (len(serverName) == 0) and not (len(variableName) == 0):
		AdminTask.setVariable(['-variableName', variableName, '-variableValue', variableValue, '-scope Cell=' + cellName])
		AdminConfig.save()
	
#----------------------------------------------------------------------------------	
# 	main
#----------------------------------------------------------------------------------
if (len(sys.argv) > 2):

	flag = sys.argv[0]
	variableName = sys.argv[1]
	
	if not (flag == 'create') and not (flag == 'remove') :
		sys.stderr.write('First argument not valid - must be create\n')
		printUsage()
		sys.exit(2)
	if (flag == 'remove'):
		cellName = sys.argv[2]
		nodeName = sys.argv[3]
		serverName = sys.argv[4]
		remove(cellName,nodeName,serverName,variableName)
		value = AdminTask.showVariables(['-variableName', variableName, '-scope Cell=' + cellName + ',Node=' + nodeName + ',Server=' + serverName])
		if (len(value) == 0):
			sys.stdout.write('WAS variable removed\n')
			sys.exit(0)
		else:
			sys.stderr.write('WAS variable could not be removed\n')
			sys.exit(1)		
	if (flag == 'create'):
		variableValue = sys.argv[2]
		cellName = sys.argv[3]
		nodeName = sys.argv[4]
		serverName = sys.argv[5]
		create(cellName,nodeName,serverName,variableName,variableValue)
		value = AdminTask.showVariables(['-variableName', variableName, '-scope Cell=' + cellName + ',Node=' + nodeName + ',Server=' + serverName])
		if (value == variableValue):
			sys.stdout.write('WAS variable created/set\n')
			sys.exit(0)
		else:
			sys.stderr.write('WAS variable could not be created/set\n')
			sys.exit(1)		
else:
	sys.stderr.write('No valid number of arguments\n')
	printUsage()
	sys.exit(2)
