##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################
#----------------------------------------------------------------------------------
#  
#       Name: disableAutoStartForApplication.py
#
#	This script disable application's auto start
#
#       Parameters:
#               cellName         - default: ctgCell01
#               nodeName         - default: ctgNode01
#               serverName       - default: MXServer
#               applicationName  - default: MAXIMO
#	Return values:
#		0 - Successfully executed
#		1 - Fail to execute
#		2 - Not valid arguments
#----------------------------------------------------------------------------------

# get line separator 
import  java
lineSeparator = java.lang.System.getProperty('line.separator')

import sys
def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split() #splits space-separated lists,
        else:
                tmpList = inStr.split("\n")   #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();         #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList


#----------------------------------------------------------------------------------
# 	Usage
#----------------------------------------------------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f disableAutoStartForApplication.py [cellName] [nodeName] [serverName] [applicationName]"
    print "		[applicationName]	is the name of the application which should be changed"
    
#----------------------------------------------------------------------------------
# 	checks whether the application exists
#		applicationName - name of the application 
#	Return:
#		true - if exists
#		false - if not 
#----------------------------------------------------------------------------------
def applicationExist(applicationName):
	installedApps = AdminApp.list()

	index = installedApps.find(applicationName)

	if (index == -1):
		return 'false'
	else:
		return 'true'
		

#----------------------------------------------------------------------------------
# 	disables applications AutoStart
#		applicationName - name of the application which should be changed
#----------------------------------------------------------------------------------
def disablesApplicationsAutoStart(applicationName):

	deployments = AdminConfig.getid("/Deployment:"+applicationName+"/")
	deploymentObj1 = AdminConfig.showAttribute(deployments, 'deployedObject')
	targetMap1 = AdminConfig.showAttribute(deploymentObj1, 'targetMappings')
	
	targetMap2 = wsadminToList(targetMap1)
	
	#targetMap1 = targetMap1.split(lineSeparator)

	for targetMapping in targetMap2:
		AdminConfig.modify(targetMapping, [["enable", "false"]])

	AdminConfig.save()
		
#----------------------------------------------------------------------------------	
# 	main
#----------------------------------------------------------------------------------
if (len(sys.argv) == 1):

	applicationName = sys.argv[0]
	
	if (applicationExist(applicationName) == 'true'):
		disablesApplicationsAutoStart(applicationName)
		sys.stdout.write("AutoStart of application " + applicationName + " disabled\n")
		sys.exit(0)
	else: 
		sys.stdout.write('Application does not exist\n')
		sys.exit(0)
else:
	sys.stderr.write('No valid number of arguments\n')
	printUsage()
	sys.exit(2)
