##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################
#----------------------------------------------------------------------------------
# 
#       Name: installApplication.py
#
#	This script installs an application
#
#       Parameters:
#               cellName         - default: ctgCell01
#               nodeName         - default: ctgNode01
#               serverName       - default: MXServer
#               applicationName  - default: MAXIMO
#               earFile          - Full qualified path to EAR file to be installed
#	Return values:
#		0 - Successfully executed
#		1 - Fail to execute
#		2 - Not valid arguments
#----------------------------------------------------------------------------------

#----------------------------------------------------------------------------------
# 	Usage
#----------------------------------------------------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f installApplication.py [cellName] [nodeName] [serverName] [applicationName] [earWithPath]"
    print "		[cellName]			is the name of cell in which the application should be installed"
    print "		[nodeName]			is the name of node in which the application should be installed"
    print "		[serverName]		is the name of server on which the application should be installed"
    print "		[applicationName]	is the name of the application which should be installed"
    print "		[earWithPath]		is the complete path including EAR file name of the application "
    
#----------------------------------------------------------------------------------
# 	checks whether the application exists
#		applicationName - name of the application 
#	Return:
#		true - if exists
#		false - if not 
#----------------------------------------------------------------------------------
def applicationExist(applicationName):
	installedApps = AdminApp.list()

	index = installedApps.find(applicationName)

	if (index == -1):
		return 'false'
	else:
		return 'true'
		

#----------------------------------------------------------------------------------
# 	install an application
#		cellName - name of cell in which the application should be installed
#		nodeName - name of node in which the application should be installed
#		serverName - name of cell in which the application should be installed
#		applicationName - name of the application which should be installed
#		earWithPath - complete path+ear file
#----------------------------------------------------------------------------------
def installApplication(cellName,nodeName,serverName,applicationName,earWithPath):

	#--------------------------------------------------------------
	# Install an application onto this server
	#--------------------------------------------------------------
	app_options = ["-server", serverName, "-node", nodeName, "-appname", applicationName]
	#-nopreCompileJSPs

	AdminApp.install(earWithPath, app_options )
	AdminConfig.save()
	
#----------------------------------------------------------------------------------	
# 	main
#----------------------------------------------------------------------------------
if (len(sys.argv) == 5):

	cellName = sys.argv[0]
	nodeName = sys.argv[1]
	serverName = sys.argv[2]
	applicationName = sys.argv[3]
	earWithPath = sys.argv[4]
	
	if (applicationExist(applicationName) == 'false'):
		installApplication(cellName,nodeName,serverName,applicationName)
		if (applicationExist(applicationName) == 'true'):
			sys.stdout.write('Application installed\n')
			sys.exit(0)
		else: 
			sys.stderr.write('Application could not be installed\n')
			sys.exit(1)
	else: 
		sys.stdout.write('Application already exist\n')
		sys.exit(0)
else:
	sys.stderr.write('No valid number of arguments\n')
	printUsage()
	sys.exit(2)
