##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################
#----------------------------------------------------------------------------------
#  
#       Name: startApplication.py
#
#	This script starts an application
#
#       Parameters:
#               cellName         - default: ctgCell01
#               nodeName         - default: ctgNode01
#               serverName       - default: MXServer
#               applicationName  - default: MAXIMO
#	Return values:
#		0 - Successfully executed
#		1 - Fail to execute
#		2 - Not valid arguments
#----------------------------------------------------------------------------------

#----------------------------------------------------------------------------------
# 	Usage
#----------------------------------------------------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f startApplication.py [cellName] [nodeName] [serverName] [applicationName]"
    print "		[cellName]			is the name of cell in which the application runs"
    print "		[nodeName]			is the name of node in which the application runs"
    print "		[serverName]		is the name of server in which the application runs"
    print "		[applicationName]	is the name of the application which should be started"
    
#----------------------------------------------------------------------------------
# 	checks whether the application exists
#		applicationName - name of the application which should be started
#	Return:
#		true - if exists
#		false - if not 
#----------------------------------------------------------------------------------
def applicationExist(applicationName):
	installedApps = AdminApp.list()

	index = installedApps.find(applicationName)

	if (index == -1):
		return 'false'
	else:
		return 'true'
		
#----------------------------------------------------------------------------------
# 	checks whether the application is started
#		applicationName - name of the application which should be stopped
#	Return:
#		true - if is started
#		false - if not 
#----------------------------------------------------------------------------------
def applicationIsStarted(cellName,nodeName,serverName,applicationName):
	status=AdminControl.completeObjectName("cell="+cellName+",node="+nodeName+",type=Application,name="+applicationName+",*")
	if (status == ""):
		return 'false'
	else:
		return 'true'
		
#----------------------------------------------------------------------------------
# 	starts the application
#		applicationName - name of the application which should be started
#----------------------------------------------------------------------------------
def startApplication(cellName,nodeName,serverName,applicationName):
	if (applicationIsStarted(cellName,nodeName,serverName,applicationName) == 'true'):
		sys.stdout.write('Application is already started\n')
	else:
		appManager = AdminControl.queryNames("cell="+cellName+",node="+nodeName+",type=ApplicationManager,process="+serverName+",*" )

		AdminControl.invoke(appManager,"startApplication",applicationName)
	
#----------------------------------------------------------------------------------	
# 	main
#----------------------------------------------------------------------------------
if (len(sys.argv) == 4):

	cellName = sys.argv[0]
	nodeName = sys.argv[1]
	serverName = sys.argv[2]
	applicationName = sys.argv[3]
	
	if (applicationExist(applicationName) == 'true'):
		startApplication(cellName,nodeName,serverName,applicationName)
		sys.stdout.write('Application started\n')
		sys.exit(0)
	else: 
		sys.stdout.write('Application does not exist\n')
		sys.exit(0)
else:
	sys.stderr.write('No valid number of arguments\n')
	printUsage()
	sys.exit(2)
