#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

# 
# Name: adaptCloudProperties.sh
#
# This script is called by "configureTSAM.sh"
# This script is not called directly by the user.
# It is not recommended to call this script directly!
#
# Sets the global properties for the Cloud Management Subsystem.
# Used variables are loaded by the script setupEnv.sh.
# Replaces the following values in the file /etc/cloud/cloud.properties:
#
# variable in file     set to value         description
# cloud-itm:1920	   $ITM_SERVER_AND_PORT full qualified name and port
#                                           of the itm server.
# itm.userid           $ITM_USER_ID         admin user id for ITM
# itm.password         $ITM_PASSWORD        admin password for ITM
# itm.soapTimeout      $ITM_SOAP_TIMEOUT    timeout value for ITM SOAP
#                                           requests
# LDAP_SERVER          $LDAP_SERVER         full qualified name of the
#                                           LDAP server.
# LDAP_PORT            $LDAP_PORT           LDAP server port. Typically
#                                           this is 389.
# LDAP_ADMIN_FULL      $LDAP_ADMIN_FULL     LDAP admin user id. By default
#                                           this is cn=root.
# LDAP_ADMIN_PW        $LDAP_ADMIN_PW       LDAP admin password.

workDir=`dirname "$0"`
. "$workDir/setupEnv.sh"

echo "sed 's/cloud-itm:1920/$ITM_SERVER_AND_PORT/' <$FILE_CLOUD_PROPERTIES >$FILE_CLOUD_PROPERTIES.tmp"
sed 's/cloud-itm:1920/$ITM_SERVER_AND_PORT/' <"$FILE_CLOUD_PROPERTIES" >"$FILE_CLOUD_PROPERTIES.tmp"
echo "sed 's/itm.userid=sysadmin/itm.userid=$ITM_USER_ID/' <$FILE_CLOUD_PROPERTIES.tmp >$FILE_CLOUD_PROPERTIES"
sed 's/itm.userid=sysadmin/itm.userid=$ITM_USER_ID/' <"$FILE_CLOUD_PROPERTIES.tmp" >"$FILE_CLOUD_PROPERTIES"

echo "sed 's/itm.password=/itm.password=********/' <$FILE_CLOUD_PROPERTIES >$FILE_CLOUD_PROPERTIES.tmp"
sed 's/itm.password=/itm.password=$ITM_PASSWORD/' <"$FILE_CLOUD_PROPERTIES" >"$FILE_CLOUD_PROPERTIES.tmp"
echo "sed 's/itm.soapTimeout=3500/itm.soapTimeout=$ITM_SOAP_TIMEOUT/' <$FILE_CLOUD_PROPERTIES.tmp >$FILE_CLOUD_PROPERTIES"
sed 's/itm.soapTimeout=3500/itm.soapTimeout=$ITM_SOAP_TIMEOUT/' <"$FILE_CLOUD_PROPERTIES.tmp" >"$FILE_CLOUD_PROPERTIES"

echo "sed 's/LDAP_SERVER=localhost/LDAP_SERVER=$LDAP_SERVER/' <$FILE_CLOUD_PROPERTIES >$FILE_CLOUD_PROPERTIES.tmp"
sed 's/LDAP_SERVER=localhost/LDAP_SERVER=$LDAP_SERVER/' <"$FILE_CLOUD_PROPERTIES" >"$FILE_CLOUD_PROPERTIES.tmp"
echo "sed 's/LDAP_PORT=389/LDAP_PORT=$LDAP_PORT/' <$FILE_CLOUD_PROPERTIES.tmp >$FILE_CLOUD_PROPERTIES"
sed 's/LDAP_PORT=389/LDAP_PORT=$LDAP_PORT$/' <"$FILE_CLOUD_PROPERTIES.tmp" >"$FILE_CLOUD_PROPERTIES"

echo "sed 's/LDAP_ADMIN_FULL=cn=root/LDAP_ADMIN_FULL=$LDAP_ADMIN_FULL/' <$FILE_CLOUD_PROPERTIES >$FILE_CLOUD_PROPERTIES.tmp"
sed 's/LDAP_ADMIN_FULL=cn=root/LDAP_ADMIN_FULL=$LDAP_ADMIN_FULL/' <"$FILE_CLOUD_PROPERTIES" >"$FILE_CLOUD_PROPERTIES.tmp"
echo "sed 's/LDAP_ADMIN_PW=time4fun/LDAP_ADMIN_PW=********/' <$FILE_CLOUD_PROPERTIES.tmp >$FILE_CLOUD_PROPERTIES"
sed 's/LDAP_ADMIN_PW=time4fun/LDAP_ADMIN_PW=$LDAP_ADMIN_PW/' <"$FILE_CLOUD_PROPERTIES.tmp" >"$FILE_CLOUD_PROPERTIES"

echo "rm -f $FILE_CLOUD_PROPERTIES.tmp"
rm -f "$FILE_CLOUD_PROPERTIES.tmp"
