#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: checkMiddleware.sh
#
# This script is called by "configureTSAM.sh"
# This script is not called directly by the user.
# It is not recommended to call this script directly!
#
# Checks if the middleware is started. Does a simple telnet
# to a given servername and a port. If this port is listening,
# telnet will return "connection closed" and nothing, if not.
# To prevent a hanging connection, the script sets the escape
# character to 'c' and quits the connection immediatelly after
# a successfull connection.

workDir=`dirname "$0"`
. "$workDir/setupEnv.sh"

# Perform a simple telnet to a port.
# If this port is not responding, the middleware part is not active.
function isPortActive
{
	SERVER=$1
	PORT=$2
	RC=0
	
	echo -n "Testing port $PORT on server $SERVER ... "
	
	LINUX_PARAM='-e c'
	
	if [[ "`uname -s`" == "AIX" ]]
	then
		export TNESC=0143
		LINUX_PARAM=""
	fi

	TELNETOUT=$(LANG=C telnet $LINUX_PARAM $1 $2 << EOF 2>/dev/null
c
quit
EOF
)


	if ! echo $TELNETOUT | grep -i "connection closed" 1>/dev/null 2>/dev/null
	then
		echo "not reachable"
		RC=1
	else
		echo "ok"
	fi
	
	return $RC

}

if isPortActive $DB2_SERVER $DB2_PORT && isPortActive $LDAP_SERVER $LDAP_PORT
then
	echo "Everything seems to be ok."
else
	echo "Parts of the Middleware are not started."
	exit 1
fi
