#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: configureMaxProperties.sh
#
# Changes maximo system properties and end point configurations.
# Sets the values directly in the database to change these
# elements.
# This is one of the two scripts called directly by the user or
# by the launchpad. All steps are writing log files to the
# Tivoli Service Automation Manager logs directory, which is
# /opt/IBM/tsam/logs by default.
# All variables are read from the script setupEnv.sh. Check setupEnv.sh
# for a list of variables to be changed.
# Currently changed system properties are
# mail.smtp.host, mxe.hostname, mxe.adminEmail,
# mxe.int.webappurl, LDAP.AdminPassword, LDAP.ServerHostName,
# LDAP.ServerPort, LDAP.AdminDN.
# Currently changed endpoint configurations are
# PMRDPRBC and PMZHBWSCR

workDir=`dirname "$0"`
SCRIPT_NAME=$0

if [[ "$workDir" =~ ^/ ]]
then
	export TSAM_CONFIG_HOME=$workDir
else
	export TSAM_CONFIG_HOME="$(pwd)"/"${workDir}"
fi

. "$workDir/setupEnv.sh"

# Enable Localization
. "$workDir/../tools/i18n.sh" configureMaxProperties

echo

# The first parameter is the scriptname without the ending .sh
function callStep
{
	CURRENT_STEP=$1
	shift;
	CURRENT_SCRIPTNAME=${CURRENT_STEP}.sh
	"$workDir/${CURRENT_SCRIPTNAME}" $@ 1>>${TSAM_LOG}/${CURRENT_STEP}_${TIMESTAMP}.log 2>>${TSAM_LOG}/${CURRENT_STEP}_${TIMESTAMP}.err
	RC=$?
	if ! [[ "$RC" == "0" ]]
	then
		printLocalizedMessage errorMessage
		echo ${TSAM_LOG}/${CURRENT_STEP}_${TIMESTAMP}.log
		echo ${TSAM_LOG}/${CURRENT_STEP}_${TIMESTAMP}.err
		echo
		printLocalizedMessage logTitle
		echo ${TSAM_LOG}/${CURRENT_STEP}_${TIMESTAMP}.log:
		tail -n 10 ${TSAM_LOG}/${CURRENT_STEP}_${TIMESTAMP}.log
		echo
		echo ${TSAM_LOG}/${CURRENT_STEP}_${TIMESTAMP}.err:
		tail -n 10 ${TSAM_LOG}/${CURRENT_STEP}_${TIMESTAMP}.err
		
		echo
		printLocalizedMessage fixAndRestart
		printLocalizedMessage pressAnyKey
		read

		exit $RC
	fi
}

function unittest
{
	if test -f "$workDir"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

if [[ "$1" == "--test" ]]
then
	unittest
fi

printLocalizedMessage logDestination

mkdir -p $TSAM_LOG

echo
printLocalizedMessage middlewareCheckLabel
callStep checkMiddleware

printLocalizedMessage maximoPropertiesSetLabel

callStep setMaximoProperty mail.smtp.host "$MAIL_SMTP_HOST"
callStep setMaximoProperty mxe.hostname "$MXE_HOSTNAME"
callStep setMaximoProperty mxe.adminEmail "$MXE_ADMINEMAIL"
callStep setMaximoProperty mxe.int.webappurl "$MXE_INT_WEBAPPURL"
callStep setMaximoProperty LDAP.AdminPassword "$LDAP_ADMIN_PW" PASSWORD
callStep setMaximoProperty LDAP.ServerHostName "$LDAP_SERVER"
callStep setMaximoProperty LDAP.ServerPort "$LDAP_PORT"
callStep setMaximoProperty LDAP.AdminDN "$LDAP_ADMIN_FULL"

printLocalizedMessage endpointPropertiesSetLabel

callStep setEndPointConfig PMRDPRBC URL "https://$MXE_HOSTNAME:$MXServer_MAXIMO_PORT/cloud/rest/projects"
callStep setEndPointConfig PMRDPRBC USERNAME "$MAXADMIN"
callStep setEndPointConfig PMRDPRBC PASSWORD "$MAXADMIN_PW"
callStep setEndPointConfig PMZHBWSCR USERNAME "$SSH_USER_NAME"
callStep setEndPointConfig PMZHBWSCR PASSWORD "$SSH_PASSWORD"

callStep stopTIO
callStep startTIO

printLocalizedMessage pressAnyKey
read
