#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: configureSSHkey.sh
#
# This script is called by "configureTSAM.sh"
# This script is not called directly by the user.
# It is not recommended to call this script directly!
# 
# Configures the SSH key required by Tivoli Provisioning Manager
# for performing configurations on remote computers.
# At first, the script creates backups of the already existing 
# RSA keys, stored in .ssh of the WebSphere System user, by default
# this should be tioadmin. Then, the SSH keygenerator creates a new
# public key with the password defined in $SSH_PASS_PHRASE. This
# key is now copied to a file named endpoint_keys in the WebSphere
# System user home directory.

workDir=`dirname "$0"`
. "$workDir/setupEnv.sh"

# Check if the files are already there. If yes, create backups.
if test -f /home/$WASRXUSER/.ssh/id_rsa
then
	mv /home/$WASRXUSER/.ssh/id_rsa /home/$WASRXUSER/.ssh/id_rsa.$TIMESTAMP
fi

if test -f /home/$WASRXUSER/.ssh/id_rsa.pub
then
	mv /home/$WASRXUSER/.ssh/id_rsa.pub /home/$WASRXUSER/.ssh/id_rsa.pub.$TIMESTAMP
fi
if test -f /home/$WASRXUSER/.ssh/config
then
	cp /home/$WASRXUSER/.ssh/config /home/$WASRXUSER/.ssh/config.$TIMESTAMP
fi

su - $WASRXUSER -c "ssh-keygen -f /home/$WASRXUSER/.ssh/id_rsa -t rsa -N \"$SSH_PASS_PHRASE\""
su - $WASRXUSER -c "cp /home/$WASRXUSER/.ssh/id_rsa.pub /home/$WASRXUSER/endpoint_keys"
su - $WASRXUSER -c "echo \"StrictHostKeyChecking no\" > /home/$WASRXUSER/.ssh/config"
su - $WASRXUSER -c "echo \"ForwardX11 no\" >> /home/$WASRXUSER/.ssh/config"
su - $WASRXUSER -c "chmod 644 /home/$WASRXUSER/.ssh/config"

# Copy public keys for the later DCM import
if ! test -d $TIO_HOME/keys/TSAM
then
	su - $WASRXUSER -c "mkdir -p $TIO_HOME/keys/TSAM"
fi

su - $WASRXUSER -c "cp /home/$WASRXUSER/.ssh/id_rsa.pub $TIO_HOME/keys/TSAM/identity.pub"
su - $WASRXUSER -c "cp /home/$WASRXUSER/.ssh/id_rsa $TIO_HOME/keys/TSAM/identity"

