#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: configureTSAM.sh
# 
# This file is directly called by the user or by the launchpad.
# If one of the steps failed and the user restarts the 
# script after repairing the error, he is asked if he wants to
# proceed on the step which failed, or if he wants to start
# from the beginning. The script also stores log files
# into the Tivoli Service Automation Manager logs file directory
# which is /opt/IBM/tsam/logs by default
# for each step performed. If something failed, the user
# sees the name of the log files linked to the failed step
# and also the last ten lines of these log files.
# All variables are read from the script setupEnv.sh. Check setupEnv.sh
# for a list of variables to be changed if you want to call this script
# without the launchpad.
# The i18n is done by the script i18n.sh.
# The following steps are performed, with their unique id:
# uniq id                               script called
# ------------------------------------  --------------------------------------
# CHECK_MIDDLEWARE                      checkMiddleware
# START_PREPARE_TIO                     startTIO
# CHANGE_APPLICATION_CLASSLOADER        changeApplClassLoaderOrderToPARENT
# CHANGE_APPLICATION_WAR_CLASSLOADER    changeApplWARClassLoaderPolicyToSINGLE
# ENABLE_CLASSLOADER_RELOAD             enableApplClassReloading
# STOP_RESTART_TIO                      stopTIO
# START_RESTART_TIO                     startTIO
# SSHKEY_STOP_TIO                       stopTIO
# SSHKEY_CONFIG                         configureSSHkey
# SSHKEY_START_TIO                      startTIO
# START_DISCOVERY_WORKFLOW				startTPMDiscoveryWorkflow
# GENERATE_IHSPLUGIN                    generateIHSPlugin


workDir=`dirname "$0"`
SCRIPT_NAME=$0

if [[ "$workDir" =~ ^/ ]]
then
	export TSAM_CONFIG_HOME=$workDir
else
	export TSAM_CONFIG_HOME="$(pwd)"/"${workDir}"
fi

. "$workDir/setupEnv.sh"

# Enable Localization
. "$workDir/../tools/i18n.sh" configureTSAMfixpack

# Ask for WebSphere credentials
printLocalizedMessage QUESTION_WAS_USER
read WASADMIN
export WASADMIN=${WASADMIN:=wasadmin}

printLocalizedMessage QUESTION_WAS_PWD
stty -echo; read WASADMIN_PW; stty echo; echo
export WASADMIN_PW=${WASADMIN_PW:=invalid}

# Ask for WebSphere Port
printLocalizedMessage QUESTION_WAS_PORT
read MXServer_MAXIMO_PORT
export MXServer_MAXIMO_PORT=${MXServer_MAXIMO_PORT:=9443}


# The first parameter is the scriptname without the ending .sh
function callStep
{
	CURRENT_STEP_ID=$1
	CURRENT_STEP=$2
	CURRENT_SCRIPTNAME=${CURRENT_STEP}.sh
	LOGFILE_NAME_PREFIX=${CURRENT_STEP_ID}_${CURRENT_STEP}_${TIMESTAMP}
	if ! test -f "$TSAM_POSTINSTALL_PROGRESS" || ! cat "$TSAM_POSTINSTALL_PROGRESS" | egrep "^$CURRENT_STEP_ID$" 1>/dev/null 2>/dev/null
	then
		"$workDir/${CURRENT_SCRIPTNAME}" 1>>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log 2>>${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
		RC=$?
		if ! [[ "$RC" == "0" ]]
		then
			printLocalizedMessage errorMessage
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err
			echo
			printLocalizedMessage logTitle
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log:
			tail -n 10 "${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.log"
			echo
			echo ${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err:
			tail -n 10 "${TSAM_LOG}/${LOGFILE_NAME_PREFIX}.err"
			
			echo
			printLocalizedMessage fixAndRestart
			printLocalizedMessage pressAnyKey
			read

			exit $RC
		fi
		echo $CURRENT_STEP_ID >> "$TSAM_POSTINSTALL_PROGRESS"
	fi

}

function unittest
{
	if test -f "$workDir"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

if [[ "$1" == "--test" ]]
then
	unittest
fi

printLocalizedMessage logDestination

mkdir -p $TSAM_LOG

if test -f "$TSAM_POSTINSTALL_PROGRESS"
then
	printLocalizedMessage warningNotClean
	read KEY
	if [[ "$KEY" == "y" ]]
	then
		printLocalizedMessage postInstallRestartLabel
		rm -f "$TSAM_POSTINSTALL_PROGRESS"
	fi	
fi

echo

printLocalizedMessage stepTSAMcomponentsLabel

callStep START_PREPARE_TIO startTIO
callStep CHANGE_APPLICATION_CLASSLOADER changeApplClassLoaderOrderToPARENT
callStep CHANGE_APPLICATION_WAR_CLASSLOADER changeApplWARClassLoaderPolicyToSINGLE
callStep ENABLE_CLASSLOADER_RELOAD enableApplClassReloading
callStep STOP_RESTART_TIO stopTIO
callStep START_RESTART_TIO startTIO

printLocalizedMessage pressAnyKey
read
