#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: setupEnv.sh
#
# This script is called by any shellscript used during
# post installation.
# This script is not called directly by the user.
# It is not recommended to call this script directly!
#
# Loads the variables into the environment, so that they can
# be used by the different scripts. To call this script, you have to
# set the variable in the environment where you want to call 
# configureTSAM.sh or configureMaxProperties.sh. If variables are not set,
# default values are used.

workDir=`dirname "$0"`

function setVariableByTIO
{
	DESTINATION_VARIABLE=$1
	TIO_ENVIRONMENT_VARIABLE=$2
	WASRXUSER=$3
	
	VALUE=$(su - $WASRXUSER	-c ". \$TIO_HOME/tools/setupCmdLine.sh; env | grep $TIO_ENVIRONMENT_VARIABLE | cut -f 2 -d =")
	eval export $DESTINATION_VARIABLE=$VALUE
}

##############################################################################
#
# several static environment variables 
#
##############################################################################

export TIMESTAMP=`date +"%d%m%y%H%M%S"`

# Set by launchpad, disk1/install/postinstall
# export TSAM_CONFIG_HOME=

# TPM
WASRXUSER=${WASRXUSER:=tioadmin}

# TSAM
export TSAM_HOME=/opt/IBM/tsam
export TSAM_POSTINSTALL_PROGRESS=$TSAM_HOME/.fpprogress
export TSAM_LOG=$TSAM_HOME/logs

# WAS
setVariableByTIO WAS_HOME WAS_HOME $WASRXUSER
setVariableByTIO WAS_PROFILE_NAME APPSRV_PROFILE $WASRXUSER
MXServer_MAXIMO_PORT=${MXServer_MAXIMO_PORT:=9443}

# Paths
export WAS_PROFILE_HOME=$WAS_HOME/profiles/$WAS_PROFILE_NAME
export WS_ADMIN_SCRIPT=$WAS_PROFILE_HOME/bin/wsadmin.sh

# Helper scripts /commands
export WS_ADMIN_SCRIPT="$WAS_PROFILE_HOME/bin/wsadmin.sh"

# Jython scripts to adapt WAS

DISABLE_AUTOSTART_FOR_APPLICATION_JYTHON="$TSAM_CONFIG_HOME/Jython/disableAutoStartForApplication.py"
CHANGE_WAR_CL_POLICY_TO_SINGLE_JYTHON="$TSAM_CONFIG_HOME/Jython/changeApplWARClassLoaderPolicyToSINGLE.py"
CHANGE_WAR_CL_ORDER_TO_PARENT_JYTHON="$TSAM_CONFIG_HOME/Jython/changeApplClassLoaderOrderToPARENT.py"
ENABLE_APPL_CLASS_RELOADING_JYTHON="$TSAM_CONFIG_HOME/Jython/enableApplClassReloading.py"

# credentials

WASADMIN=${WASADMIN:=wasadmin}
WASADMIN_PW=${WASADMIN_PW:=}

















# LDAP



# MAXIMO PROPERTIES




