#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: validateInstallationParameters.sh
workDir=`dirname "$0"`
SCRIPT_NAME=$0

if [[ "$workDir" =~ ^/ ]]
then
	export TSAM_CONFIG_HOME=$workDir
else
	export TSAM_CONFIG_HOME="$(pwd)"/"${workDir}"
fi

. "$workDir/setupEnv.sh"

# Enable Localization
. "$workDir/../tools/i18n.sh" validateInstallationParameters

RC=0

echo

function checkIfUserExists
{
	printLocalizedMessage VerifyUser
	echo $1
	grep $1 /etc/passwd 1>/dev/null 2>&1
	if [[ "$?" == "0" ]]
	then
		printLocalizedMessage UserVerified
	else
		printLocalizedMessage UserNotVerified
		RC=1
	fi
}

function isPortActive
{
	printLocalizedMessage VerifyServer
	SERVER=$1
	PORT=$2
	echo ${SERVER}:${PORT}
	
	RC=0
	
	LINUX_PARAM='-e c'
	
	if [[ "`uname -s`" == "AIX" ]]
	then
		export TNESC=0143
		LINUX_PARAM=""
	fi

	TELNETOUT=$(LANG=C telnet $LINUX_PARAM $1 $2 << EOF 2>/dev/null
c
quit
EOF
)

	if ! echo $TELNETOUT | grep -i "connection closed" 1>/dev/null 2>/dev/null
	then
		RC=1
	fi
	
	if [[ "$RC" == "0" ]]
	then
		printLocalizedMessage ServerVerified
	else
		printLocalizedMessage ServerNotVerified
		RC=1
	fi

}
# Check user existences
checkIfUserExists $WASRXUSER
checkIfUserExists $SSH_USER_NAME
checkIfUserExists $DB2ADMIN
checkIfUserExists $DB2MAXIMOUSER

# Check server and port
isPortActive ${DB2_SERVER} ${DB2_PORT}
isPortActive ${LDAP_SERVER} ${LDAP_PORT}
isPortActive ${TPM_PROV_SERVERNAME} ${MXServer_MAXIMO_PORT}

printLocalizedMessage pressAnyKey
read
