------------------------------------------------------------------
-- Licensed Materials - Property of IBM
-- 5724-W78
-- (C) Copyright IBM Corp. 2010
-- All Rights Reserved
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
------------------------------------------------------------------

-- remove the REST service, as base services 7.1.1.6 installs them
delete from maxservice where servicename = 'REST' ;

-- fix hard-coded class ancestor id and use sequence. Avoids an upgrade error
update classancestor set classancestorid=nextval for classancestoruseq where classstructureid='8100091' and ancestor='8100091' ;

-- remove vmware discovery, as this will be recreated when installing the vmware tcdriver
DELETE from dcm_policy where dcm_object_id in (select id from dcm_object where name = 'VMware VI3 - Virtual Center Template Discovery') ;
DELETE from discovery_execution where discovery_id in (select id from dcm_object where name = 'VMware VI3 - Virtual Center Template Discovery') ;
DELETE from discovery_last_scan where discovery_id in (select id from dcm_object where name = 'VMware VI3 - Virtual Center Template Discovery') ;
DELETE from discovery where discovery_id in (select id from dcm_object where name = 'VMware VI3 - Virtual Center Template Discovery') ;
DELETE from  access_domain_membership where dcm_object_id in (select id from dcm_object where name = 'VMware VI3 - Virtual Center Template Discovery') ;
DELETE from dcm_object where id in (select id from dcm_object where name = 'VMware VI3 - Virtual Center Template Discovery') ;

-- this fix is required by SRM 7.2 upgrade, adding here since the sql is idempotent and this avoids another point that can be missed
update autokey set seed=(select max(reportnum) from report) + 1 where autokeyname='REPORTNUM' ; 

-- remove obsolete REST API object structures and filter domains 
-- Cleanup of old TSAM 7.2 Object Structures:
delete from maxintobject where intobjectname like 'PMZHBR1%' and intobjectname not in ('PMZHBR1_PERSGRPTM','PMZHBR1_PERSGRPTMDET','PMZHBR1_PERSNTINTEAM') ;
delete from maxintobjdetail where intobjectname like 'PMZHBR1%' and intobjectname not in ('PMZHBR1_PERSGRPTM','PMZHBR1_PERSGRPTMDET','PMZHBR1_PERSNTINTEAM');
delete from maxintobjcols where intobjectname like 'PMZHBR1%' and intobjectname not in ('PMZHBR1_PERSGRPTM','PMZHBR1_PERSGRPTMDET','PMZHBR1_PERSNTINTEAM') ;
delete from maxintobjalias where intobjectname like 'PMZHBR1%' and intobjectname not in ('PMZHBR1_PERSGRPTM','PMZHBR1_PERSGRPTMDET','PMZHBR1_PERSNTINTEAM') ;

-- Cleanup of old Filter domains: (Table Domains)
delete from maxdomain where domainid in ('PMZHBT_BKUPIMAGES') and domaintype = 'TABLE' ;
delete from maxtabledomain where domainid in ('PMZHBT_BKUPIMAGES') ;

-- delete image library entries that don't have a matching software stack or vst. this means they don't 
-- have an image in the backend. 
DELETE FROM ILIMAGE
 WHERE IMAGEID IN ((SELECT IL.IMAGEID
               FROM ILIMAGE AS IL 
                    LEFT OUTER JOIN TPSOFTWARESTACK AS ST ON IL.SOFTWARESTACKID = ST.STACK_ID 
                    LEFT OUTER JOIN TPVIRTUALSERVERTEMPLATE AS VST ON IL.VIRTUALSERVERTEMPLATEID = VST.ID
                    LEFT OUTER JOIN TPVIRTUALSERVERTEMPLATE AS MIN_VST ON IL.VIRTUALSERVERTEMPLATEMINID = MIN_VST.ID
               WHERE ST.STACK_ID IS NULL OR VST.ID IS NULL OR MIN_VST.ID IS NULL));
               
               
-- remove modify server resources operation. The operation will be recreated in the installation and the link to it will 
-- be fixed by the upgrade package. This operation only exists when the 7.2.0.2 migration manager package has also
-- been installed
DELETE FROM PMZHBWTNOPIF
 WHERE OPERATION_ID IN ((SELECT PMZHBWTNOPID
                    FROM PMZHBWTNOP
                    WHERE OPNUM = 'MODSRVRES' AND OPOWNER = 'PMRDP'));

DELETE FROM PMZHBWTNOP
 WHERE OPNUM = 'MODSRVRES' AND OPOWNER = 'PMRDP';


