#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

#
# Name: i18n.sh
#
# This script is called by any script which needs
# i18n functionality
# This script is not called directly by the user.
# It is not recommended to call this script directly!
#
# The calling script commits the prefix of the property file
# where the NLS properties are stored during the first call
# of this script as parameter. Now, the calling script
# can execute the function printLocalizedMessage, which takes
# a single paramter, representing a key in the property file.
# To get the used language, the command locale is used and here
# the output for the key LC_CTYPE.
# If a property file for the found language is not found,
# english is used as fallback.

function printLocalizedMessage
{
   FILE_NAME_PREFIX=$I18N_PROPERTY_FILE_PREFIX
   MESSAGE_KEY=$1
   LOCALE_EXTENSION=`locale | grep LC_CTYPE | cut -f 2 -d = | cut -f 1 -d . | sed "s/\"//g"`
   
   # If there is no slash before the current file, add the current directory.
   ABSOLUTE_PATH=`dirname "$SCRIPT_NAME"`/
   if ! [[ "$ABSOLUTE_PATH" =~ ^/ ]]
   then
      ABSOLUTE_PATH=`pwd`/$ABSOLUTE_PATH
   fi
	
   FILE_NAME="${ABSOLUTE_PATH}nls/${FILE_NAME_PREFIX}_${LOCALE_EXTENSION}.properties"
   if ! test -f "$FILE_NAME"
   then
      LOCALE_EXTENSION=`echo $LOCALE_EXTENSION | cut -f 1 -d _`
      FILE_NAME="${ABSOLUTE_PATH}nls/${FILE_NAME_PREFIX}_${LOCALE_EXTENSION}.properties"
      if ! test -f "$FILE_NAME"
      then
         FILE_NAME="${ABSOLUTE_PATH}nls/$FILE_NAME_PREFIX.properties"
      fi
   fi
   if test -f "$FILE_NAME"
   then
      MESSAGE=$(eval "echo \"$(cat "$FILE_NAME"|grep $MESSAGE_KEY|cut -f 2 -d =)\"")
   else
      MESSAGE="*** ERROR: Unable to read properties file $FILE_NAME"
   fi

   echo "$MESSAGE"
}

if [[ "$1" == "--test" ]]
then
	exit 0
fi

SCRIPT_NAME=$0
I18N_PROPERTY_FILE_PREFIX=$1
