#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

# Flags:
# -t               TPM TIO Administartive User ID (Default: tioadmin)
# -h               Show Usage

# Get the absolute path to the drivers relative to this script
ABSOLUTE_PATH=`dirname "$0"`/
if ! [[ "$ABSOLUTE_PATH" =~ ^/ ]]
then
	ABSOLUTE_PATH=`pwd`/$ABSOLUTE_PATH
fi

# Enable Localization
. "$ABSOLUTE_PATH/i18n.sh" installAutomationPackages

DRIVERLIST="tcdriver.list"
FILEENDING=".tcdriver"
SCRIPT_NAME=$0

echo

function printUsage
{
   echo "$0 [-t tioadminusername] [-h]"
}

function unittest
{
	if test -f "$ABSOLUTE_PATH"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

# prepare TIO user id
TIO_USER=

while [ "$#" -ne "0" ]
do
   case $1 in
   	  "--test") unittest; shift;;
	  "-t") TIO_USER=$2; shift; shift;;
	  "-h") printUsage; exit 1;;
      *) printUsage; exit 1;;
   esac
done

# Ask for TIO user if not set yet
if [[ "$TIO_USER" == "" ]]
then
   printLocalizedMessage QUESTION_TIO_USER
   read TIO_USER
   TIO_USER=${TIO_USER:=tioadmin}
fi

# Install the tcdrivers
TIO_HOME=`su - tioadmin -c 'echo $TIO_HOME'`
cd "$CURRENTDIR" 
printLocalizedMessage installAutomationPackages

TCDRIVERSOURCEPATH=${ABSOLUTE_PATH}../tcdriver/

for TCDRIVER in `cat "${TCDRIVERSOURCEPATH}"${DRIVERLIST} | grep -v "^#"`
do
  # TCDRIVERSOURCE contains the full source path plus the driver name
  TCDRIVERSOURCE=${TCDRIVERSOURCEPATH}${TCDRIVER}
  # NAME contains the name of the driver without the file ending
  NAME=`basename $TCDRIVERSOURCE $FILEENDING`
  # the driver install option: i=install, fid=forced install
  OPTIONS=fid
  # log output
  TIMESTAMP=`date +"%d%m%y%H%M%S"`
  LOGFILE=\$TIO_LOGS/${NAME}${FILEENDING}.install.${TIMESTAMP}.log

  # copy as root to ensure access to source package
  cp "$TCDRIVERSOURCE" "$TIO_HOME"/drivers
  chown ${TIO_USER}.${TIO_USER} "${TIO_HOME}/drivers/${TCDRIVER}"
  chmod 775 "${TIO_HOME}/drivers/${TCDRIVER}"
  
  # Install the drivers (as TIO user)
  su - ${TIO_USER} -c "\$TIO_HOME/tools/tc-driver-manager.sh $OPTIONS $NAME > $LOGFILE"
  su - ${TIO_USER} -c "tail -n 4 $LOGFILE"
done
printLocalizedMessage pressAnyKey
read
