#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

# Get the absolute path to the drivers relative to this script
ABSOLUTE_PATH=`dirname "$0"`/
if ! [[ "$ABSOLUTE_PATH" =~ ^/ ]]
then
	ABSOLUTE_PATH=`pwd`/$ABSOLUTE_PATH
fi

# Enable Localization
. "$ABSOLUTE_PATH/i18n.sh" installConfigFiles

echo

function printUsage
{
   echo "$0 [-t tioadminusername] [-c WASCellName] [-h]"
}

function unittest
{
	if test -f "$ABSOLUTE_PATH"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

TIO_USER=
CELL_NAME=

# Flag handling
while [ "$#" -ne "0" ]
do
   case $1 in
      "--test") unittest; shift;;
	  "-t") TIO_USER=$2; shift; shift;;
	  "-c") CELL_NAME=$2; shift; shift;;
	  "-h") printUsage; exit 1;;
      *) printUsage; exit 1;;
   esac
done

# Ask for TIO credentials
if [[ "$TIO_USER" == "" ]]
then
   printLocalizedMessage QUESTION_TIO_USER
   read TIO_USER
   TIO_USER=${TIO_USER:=tioadmin}
fi

# Ask for WebSphere Cell name
if [[ "$CELL_NAME" == "" ]]
then
   printLocalizedMessage QUESTION_WAS_CELL
   read CELL_NAME
   CELL_NAME=${CELL_NAME:=ctgCell01}
fi

CURRENT_DIR=`pwd`
CLOUD_CONFIG_TAR=${ABSOLUTE_PATH}/../files/cloudConfig.tar
CLOUD_CONFIG_TAR_DIR=/etc/cloud
CLOUD_POSTINST_ZIP=${ABSOLUTE_PATH}/../files/cloudPostinstallWindows.zip
CLOUD_POSTINST_ZIP_DIR=/opt/IBM/tsam/files
#ILPMPPLUGINZIP=${ABSOLUTE_PATH}/../tcdriver/il_pmp_plugin.zip

WORKSPACE=$1

# Get the path where the businessobjects.jar is stored
SETUPCMDLINE=". \$TIO_HOME/tools/setupCmdLine.sh"
# path to the "Master"-businessobjects.jar
BOPATH="\$WAS_HOME/profiles/\$APPSRV_PROFILE/installedApps/$CELL_NAME/MAXIMO.ear/businessobjects.jar"
# Copy the files to the needed directories
su - ${TIO_USER} -c "$SETUPCMDLINE; cp ${BOPATH} \$TIO_HOME/eclipse/plugins/tpm_pmp/maximoLibs"
su - ${TIO_USER} -c "$SETUPCMDLINE; cp ${BOPATH} \$TIO_HOME/lwi/runtime/tpm/eclipse/plugins/tpm_pmp/maximoLibs"

# Create CSR default directory
mkdir -p /var/IBM/TSAM/metering
chown -R ${TIO_USER}.${TIO_USER} /var/IBM/TSAM/metering

## Extract image library plugin zip file
#TIO_PLUGIN_HOME=$(su - ${TIO_USER} -c "echo \$TIO_HOME/lwi/runtime/tpm/eclipse/plugins")
#cd "${TIO_PLUGIN_HOME}"
#unzip -o "${ILPMPPLUGINZIP}"
#chown -R ${TIO_USER}.${TIO_USER} "${TIO_PLUGIN_HOME}"

# Extract cloud config files
cd "${CURRENT_DIR}"
printLocalizedMessage extractCloudConfigFiles
mkdir -p "${CLOUD_CONFIG_TAR_DIR}"
cd "${CLOUD_CONFIG_TAR_DIR}"
tar -xvf "${CLOUD_CONFIG_TAR}"
chown -R ${TIO_USER}.${TIO_USER} "${CLOUD_CONFIG_TAR_DIR}"

# Copy cloud postinst zip
cd "${CURRENT_DIR}"
mkdir -p "${CLOUD_POSTINST_ZIP_DIR}"
cd "${CLOUD_POSTINST_ZIP_DIR}"
cp "${CLOUD_POSTINST_ZIP}" .
chown -R ${TIO_USER}.${TIO_USER} *

cd "${CURRENT_DIR}"

printLocalizedMessage pressAnyKey
read
