#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

# Flags:
# -t               TPM TIO Administartive User ID (Default: tioadmin)
# -o               TPM for OSD installation path (Default: /opt/IBM/tpmfos)
# -p               TPM for Images package path (No default)
# -h               Show Usage

# Get the absolute path to the drivers relative to this script
ABSOLUTE_PATH=`dirname "$0"`/
if ! [[ "$ABSOLUTE_PATH" =~ ^/ ]]
then
	ABSOLUTE_PATH=`pwd`/$ABSOLUTE_PATH
fi

# Enable Localization
. "$ABSOLUTE_PATH/i18n.sh" installTPMfI

DRIVERLIST="tcdriver.list"
FILEENDING=".tcdriver"
SCRIPT_NAME=$0

echo

function printUsage
{
   echo "$0 [-t tioadminusername] [-o tpmfosd_installdir] [-p tpmfi_package_path] [-h]"
}

function unittest
{
	if test -f "$ABSOLUTE_PATH"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

# prepare TIO user id
TIO_USER=
TPMFOSD_INSTALLATION_DIR=
TPMFI_PACKAGE_PATH=

while [ "$#" -ne "0" ]
do
   case $1 in
   	  "--test") unittest; shift;;
	  "-t") TIO_USER=$2; shift; shift;;
	  "-o") TPMFOSD_INSTALLATION_DIR=$2; shift; shift;;
	  "-p") TPMFI_PACKAGE_PATH=$2; shift; shift;;
	  "-h") printUsage; exit 1;;
      *) printUsage; exit 1;;
   esac
done

# Ask for TIO user if not set yet
if [[ "$TIO_USER" == "" ]]
then
   printLocalizedMessage QUESTION_TIO_USER
   read TIO_USER
   TIO_USER=${TIO_USER:=tioadmin}
fi

# Ask for TPMfOSD installation directory if not set yet
if [[ "$TPMFOSD_INSTALLATION_DIR" == "" ]]
then
   printLocalizedMessage QUESTION_TPMFOSD_DIR
   read TPMFOSD_INSTALLATION_DIR
   TPMFOSD_INSTALLATION_DIR=${TPMFOSD_INSTALLATION_DIR:=/opt/IBM/tpmfos}
fi

# Ask for TPMfI package if not set yet
if [[ "$TPMFI_PACKAGE_PATH" == "" ]]
then
   printLocalizedMessage QUESTION_TPMFI_PATH
   read TPMFI_PACKAGE_PATH
fi

# Check for TPMfOSD
if ! test -d ${TPMFOSD_INSTALLATION_DIR}
then
	printLocalizedMessage tpmfosddirectorynotfound
	printLocalizedMessage pressAnyKey
	read
	exit 1
fi

# Set Variables
CURRENT_DIR=`pwd`
SETUPCMDLINE=". \$TIO_HOME/tools/setupCmdLine.sh"
TPMFI_PACKAGE_PATH=${ABSOLUTE_PATH}/../TPMfI/${TPMFI_PACKAGE_PATH}

# Check for TPMfI
if ! test -f ${TPMFI_PACKAGE_PATH}
then
	printLocalizedMessage tpmfifilenotfound
	printLocalizedMessage pressAnyKey
	read
	exit 1
fi

# Stop Rembo processes
if uname -s | grep -i AIX 1>/dev/null 2>/dev/null
then
	/etc/rc.d/init.d/dbgw stop
	/etc/rc.d/init.d/rembo stop
	/etc/rc.d/init.d/rbagent stop
else
	/etc/init.d/dbgw stop
	/etc/init.d/rembo stop
	/etc/init.d/rbagent stop
fi

# Waiting until rembo is unlocking files.
sleep 15

# Extract TPM for Images into the tpmfosd directory
printLocalizedMessage tpmfiinstallation
cd ${TPMFOSD_INSTALLATION_DIR}/..
gzip -cd ${TPMFI_PACKAGE_PATH} | tar -xvf -

# Copy tar.gz to $TIO_HOME/repository/tpmfosd/
#su - ${TIO_USER} -c "$SETUPCMDLINE; cp $TPMFI_PACKAGE_PATH \$TIO_HOME/repository/tpmfosd"
TIO_HOME=$(su - ${TIO_USER} -c "echo \$TIO_HOME")
cp $TPMFI_PACKAGE_PATH $TIO_HOME/repository/tpmfosd
chown ${TIO_USER}.${TIO_USER} $TIO_HOME/repository/tpmfosd/$(basename $TPMFI_PACKAGE_PATH)

# Start Rembo processes
if uname -s | grep -i AIX 1>/dev/null 2>/dev/null
then
	/etc/rc.d/init.d/dbgw start
	/etc/rc.d/init.d/rembo start
	/etc/rc.d/init.d/rbagent start
else
	/etc/init.d/dbgw start
	/etc/init.d/rembo start
	/etc/init.d/rbagent start
fi

cd ${CURRENT_DIR}
printLocalizedMessage pressAnyKey
read
