#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

# Flags:
# -u               Websphere Administrative User ID (Default: wasadmin)
# -p               Websphere Administrative User Password
# -t               TPM TIO Administartive User ID (Default: tioadmin)
# -h               Show Usage

# Get the absolute path to the drivers relative to this script
ABSOLUTE_PATH=`dirname "$0"`/
if ! [[ "$ABSOLUTE_PATH" =~ ^/ ]]
then
	ABSOLUTE_PATH=`pwd`/$ABSOLUTE_PATH
fi

# Enable Localization
. "$ABSOLUTE_PATH/i18n.sh" prepareServer

function printUsage
{
   echo "$0 [-u WASUsername] [-p WASPassword] [-t tioadminusername] [-h]"
}

function unittest
{
	if test -f "$ABSOLUTE_PATH"/$(basename "$SCRIPT_NAME") && ! printLocalizedMessage a | grep "^[*][*][*]" 1>/dev/null 2>/dev/null
	then
		exit 0
	else
		exit 1
	fi
}

TIO_USER=
WAS_USER=
WAS_PWD=

while [ "$#" -ne "0" ]
do
   case $1 in
      "--test") unittest; shift;;
      "-u") WAS_USER=$2; shift; shift;;
      "-p") WAS_PWD=$2; shift; shift;;
	  "-t") TIO_USER=$2; shift; shift;;
	  "-h") printUsage; exit 1;;
      *) printUsage; exit 1;;
   esac
done

# Ask for Websphere credentials
if [[ "$WAS_USER" == "" ]]
then
   printLocalizedMessage QUESTION_WAS_USER
   read WAS_USER
   WAS_USER=${WAS_USER:=wasadmin}
fi

if [[ "$WAS_PWD" == "" ]]
then
   printLocalizedMessage QUESTION_WAS_PWD
   stty -echo; read WAS_PWD; stty echo; echo
   WAS_PWD=${WAS_PWD:=invalid}
fi

# Ask for TIO credentials
if [[ "$TIO_USER" == "" ]]
then
   printLocalizedMessage QUESTION_TIO_USER
   read TIO_USER
   TIO_USER=${TIO_USER:=tioadmin}
fi

# Load Environment Variables from TPM
SETUPCMDLINE=". \$TIO_HOME/tools/setupCmdLine.sh"

# Stop TPM LWI
printLocalizedMessage STOP_LWI
su - $TIO_USER -c "${SETUPCMDLINE}; \$TIO_HOME/tools/tio.sh stop tpm"
echo $?

# Start TPM Websphere components
printLocalizedMessage START_WEBSPHERE
su - $TIO_USER -c "${SETUPCMDLINE}; \$TIO_HOME/tools/tio.sh start -w $WAS_USER $WAS_PWD"
echo $?

# Stop Application Server
printLocalizedMessage STOP_APPSERVER
su - $TIO_USER -c "${SETUPCMDLINE}; \$WAS_HOME/bin/stopServer.sh \$APPSERVER_NAME -profileName \$APPSRV_PROFILE -username $WAS_USER -password $WAS_PWD; exit $?"
echo $?

printLocalizedMessage pressAnyKey
read
