#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

# CHANGE THE VARIABLES BELOW

# REMOVE THIS LINE IF CONFIGURED PROPERLY
echo "PLEASE CONFIGURE THIS SCRIPT AND REMOVE THIS LINE AFTERWARDS INSIDE THE SCRIPT"; exit 1
# REMOVE THIS LINE IF CONFIGURED PROPERLY

LOGDIR=/var/log/mwi

DB2USER=ctginst1
DB2_CCMDB_INSTANCE_PORT=50005

LDAPPATH=/opt/ibm/ldap/V6.2
LDAP_PORT=389

HTTPPATH=/opt/IBM/HTTPServer

LDAPDB2INSTANCE=idsccmdb
LDAPROOTUSER="cn=root"
LDAPROOTPASSWORD=""

WASPATH=/opt/IBM/WebSphere/AppServer
WASADMUSR=wasadmin
WASADMPWD=""
WAS_DMGR_PORT=9043
WAS_DMGR_PROFILE_NAME=ctgDmgr01
WAS_APPSRV_PORT=9443
WAS_APPSRV_PROFILE_NAME=ctgAppSrv01
WAS_APPSRV_NAME=MXServer


##################################################################
#### DO NOT CHANGE BELOW HERE !!!
##################################################################

TIMESTAMP=`date +"%d%m%y%H%M%S"`

if [ "$LDAPROOTPASSWORD" == "" ] || [ "$WASADMPWD" == "" ]
then
   echo "File not properly configured."
   exit 1
fi

if ! test -d ${LOGDIR}
then
   mkdir ${LOGDIR}
fi

function startMiddleware
{
	echo "Starting the Middleware"
	echo "-----------------------"
	echo "Using Log directory ${LOGDIR}"
	echo "Using Timestamp ${TIMESTAMP}"
	echo "Using DB2 Instance ${DB2USER}"
	echo "Using LDAP DB2 Instance ${LDAPDB2INSTANCE}"
	echo "Using LDAP Path ${LDAPPATH}"
	echo "Using LDAP admin user ${LDAPROOTUSER}"
	echo "Using HTTP Server Path ${HTTPPATH}"
	echo "Using Websphere Path ${WASPATH}"

	echo ""

	echo "Starting DB2 instance..."
	su - ${DB2USER} -c db2start 1>> ${LOGDIR}/db2_${DB2USER}_${TIMESTAMP}.out 2>> ${LOGDIR}/db2_${DB2USER}_${TIMESTAMP}.err

	echo "Starting LDAP Server..."
	${LDAPPATH}/sbin/idsdiradm -I ${LDAPDB2INSTANCE} 1>> ${LOGDIR}/idsdiradm_${TIMESTAMP}.out 2>> ${LOGDIR}/idsdiradm_${TIMESTAMP}.err
	${LDAPPATH}/sbin/ibmslapd -I ${LDAPDB2INSTANCE} 1>> ${LOGDIR}/ibmslapd_${TIMESTAMP}.out 2>> ${LOGDIR}/ibmslapd_${TIMESTAMP}.err
	${LDAPPATH}/bin/idsdirctl -D ${LDAPROOTUSER} -w ${LDAPROOTPASSWORD} start 1>> ${LOGDIR}/idsdirctl_${TIMESTAMP}.out 2>> ${LOGDIR}/idsdirctl_${TIMESTAMP}.err

	echo "Starting HTTP Server..."
	${HTTPPATH}/bin/apachectl start 1>> ${LOGDIR}/httpserver_${TIMESTAMP}.out 2>> ${LOGDIR}/httpserver_${TIMESTAMP}.err

	echo "Starting Websphere Manager and Node..."
	${WASPATH}/profiles/${WAS_DMGR_PROFILE_NAME}/bin/startManager.sh 1>> ${LOGDIR}/websphere_manager_${TIMESTAMP}.out 2>> ${LOGDIR}/websphere_manager_${TIMESTAMP}.err
	${WASPATH}/profiles/${WAS_APPSRV_PROFILE_NAME}/bin/startNode.sh 1>> ${LOGDIR}/websphere_node_${TIMESTAMP}.out 2>> ${LOGDIR}/websphere_node_${TIMESTAMP}.err
	${WASPATH}/profiles/${WAS_APPSRV_PROFILE_NAME}/bin/startServer.sh ${WAS_APPSRV_NAME} 1>> ${LOGDIR}/websphere_server_${TIMESTAMP}.out 2>> ${LOGDIR}/websphere_server_${TIMESTAMP}.err
}

function check_port
{
   if netstat -an | grep LISTEN | grep $1 1>/dev/null 2>/dev/null
   then
      return 0
   else
      return 1
   fi
}

function check_unit
{
   echo -en $1
   shift
   while ! [ "$#" == 0 ]
   do
     if ! check_port $1
	 then
	    echo -en "NOT STARTED\n"
	    RC=1
     fi
	 shift
   done
   echo -en "OK\n"
}

function stopMiddleware
{
	echo "Stopping the Middleware"
	echo "-----------------------"
	echo "Using Log directory ${LOGDIR}"
	echo "Using Timestamp ${TIMESTAMP}"
	echo "Using DB2 Instance ${DB2USER}"
	echo "Using LDAP DB2 Instance ${LDAPDB2INSTANCE}"
	echo "Using LDAP Path ${LDAPPATH}"
	echo "Using LDAP admin user ${LDAPROOTUSER}"
	echo "Using HTTP Server Path ${HTTPPATH}"
	echo "Using Websphere Path ${WASPATH}"
	
	echo ""
	
	echo "Stopping DB2 instance..."
	su - ${DB2USER} -c db2stop 1>> ${LOGDIR}/db2_${DB2USER}_${TIMESTAMP}.out 2>> ${LOGDIR}/db2_${DB2USER}_${TIMESTAMP}.err
	
	echo "Stopping Websphere Manager and Node..."
	${WASPATH}/profiles/${WAS_APPSRV_PROFILE_NAME}/bin/stopServer.sh ${WAS_APPSRV_NAME} -username ${WASADMUSR} -password ${WASADMPWD} 1>> ${LOGDIR}/websphere_server_${TIMESTAMP}.out 2>> ${LOGDIR}/websphere_server_${TIMESTAMP}.err
	${WASPATH}/profiles/${WAS_APPSRV_PROFILE_NAME}/bin/stopNode.sh -username ${WASADMUSR} -password ${WASADMPWD} 1>> ${LOGDIR}/websphere_node_${TIMESTAMP}.out 2>> ${LOGDIR}/websphere_node_${TIMESTAMP}.err
	${WASPATH}/profiles/${WAS_DMGR_PROFILE_NAME}/bin/stopManager.sh -username ${WASADMUSR} -password ${WASADMPWD} 1>> ${LOGDIR}/websphere_manager_${TIMESTAMP}.out 2>> ${LOGDIR}/websphere_manager_${TIMESTAMP}.err
		
	echo "Stopping LDAP Server..."
	su - ${LDAPDB2INSTANCE} -c db2stop 1>> ${LOGDIR}/db2_${LDAPDB2INSTANCE}_${TIMESTAMP}.out 2>> ${LOGDIR}/db2_${LDAPDB2INSTANCE}_${TIMESTAMP}.err
	${LDAPPATH}/bin/idsdirctl -D ${LDAPROOTUSER} -w ${LDAPROOTPASSWORD} stop 1>> ${LOGDIR}/idsdirctl_${TIMESTAMP}.out 2>> ${LOGDIR}/idsdirctl_${TIMESTAMP}.err
		
	echo "Stopping HTTP Server..."
	${HTTPPATH}/bin/apachectl stop 1>> ${LOGDIR}/httpserver_${TIMESTAMP}.out 2>> ${LOGDIR}/httpserver_${TIMESTAMP}.err
}

function verifyMiddleware
{
   echo "Verifying the Middleware"
   RC=0
   check_unit "Checking DB2..." ${DB2_CCMDB_INSTANCE_PORT}
   check_unit "Checking IBM Directory Server..." ${LDAP_PORT}
   check_unit "Checking Websphere..." ${WAS_DMGR_PORT} ${WAS_APPSRV_PORT}
   exit $RC
}

case "$1" in
   start)
      startMiddleware
      ;;
   stop)
      stopMiddleware
      ;;
   restart)
      stopMiddleware
      startMiddleware
      ;;
   status)
      verifyMiddleware
      ;;
   *)
      echo $"Usage: $0 {start|stop|restart|status}"
      ;;
   esac
   
