#!/bin/bash
##################################################################
# Licensed Materials - Property of IBM
# 5724-W78
# (C) Copyright IBM Corp. 2010
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##################################################################

# Set variables to default values
RC_OK=0
RC_WARNING=10
RC_ERROR=20
RC_UNKNOWNOS=99

STATUS=$RC_OK

SILENT=0
SEPERATED=0
OUTPUTLIST=""
DEBUG=0

TMPFILE=/tmp/tsam_lp.tmp

# Print text on screen if not called in silent mode
function printOnScreen
{
   if [ "$SILENT" == "0" ] && [ "$SEPERATED" == "0" ]
   then
      echo -en $1
   fi
	   
}

# If $DEBUG is 0, return false, if $DEBUG is 1, return true
function isDebug
{
        RETVAL=$(($(($DEBUG+1))%2))
        return $RETVAL
}

# Print usage on screen
function printUsage
{
   printOnScreen "Usage:\n"
   printOnScreen "   $0 [-c] [-s]\n"
}

while [ "$#" -ne "0" ]
do
   case $1 in
      "-s") SILENT=1; shift;;
      "-c") SEPERATED=1; shift;;
      "-d") DEBUG=1; shift;;
      *) printUsage; exit 1;;
   esac
done

function printOutputList
{
   if [ "$SILENT" == "0" ] && [ "$SEPERATED" == "1" ]
   then
      echo ${OUTPUTLIST} > ${TMPFILE}
   fi
}

function printValidOutputList
{
   if [ "$SILENT" == "0" ] && [ "$SEPERATED" == "1" ] && [ "$STATUS" == "$RC_OK" ]
   then
      echo ${VALIDOUTPUTLIST} > ${TMPFILE}
   fi
}

function addToList
{
   if [ "$OUTPUTLIST" == "" ]
   then
      OUTPUTLIST=$1
   else
      OUTPUTLIST=${OUTPUTLIST},$1
   fi
}

function addToValidList
{
   if [ "$VALIDOUTPUTLIST" == "" ]
   then
      VALIDOUTPUTLIST=$1
   else
      VALIDOUTPUTLIST=${VALIDOUTPUTLIST},$1
   fi
}

function verify_os
{
   printOnScreen "Verifying operating System..."
   
   if isDebug || ! uname -s | grep -i AIX 1>/dev/null 2>/dev/null
   then
      printOnScreen "ERROR\n"
      STATUS=${RC_UNKNOWNOS}
   else
      printOnScreen "OK\n"
   fi
}

function verify_package
{
   PACKAGENAME=$1
   
   printOnScreen "Verifying package $PACKAGENAME..."
   lslpp -Lc | grep -i $PACKAGENAME 1> /dev/null 2> /dev/null
   
   if ! [ "$?" == "0" ] || isDebug
   then
      printOnScreen "ERROR\n"
      STATUS=${RC_ERROR}
      addToList $PACKAGENAME
   else
      if ! echo $PACKAGENAME | grep "^X11" 1>/dev/null 2>/dev/null
      then
         addToValidList `lslpp -Lc | grep -i $PACKAGENAME | cut -d ':' -f 2,3`
      fi
      printOnScreen "OK\n"
   fi
}

function verify_packages
{
   verify_package bash
   verify_package bash-doc
   verify_package cairo
   verify_package curl
   verify_package expect
   verify_package glib
   verify_package gtk2
   verify_package perl
   verify_package procmail
   verify_package tcl
   verify_package tk
   verify_package unzip
   verify_package wget
   verify_package openssh
   verify_package openssl
   verify_package X11.adt.bitmaps
   verify_package X11.adt.ext
   verify_package X11.adt.imake
   verify_package X11.adt.include
   verify_package X11.adt.lib
   verify_package X11.adt.motif
   verify_package X11.apps.aixterm
   verify_package X11.apps.clients
   verify_package X11.apps.config
   verify_package X11.apps.custom
   verify_package X11.apps.msmit
   verify_package X11.apps.rte
   verify_package X11.apps.util
   verify_package X11.apps.xdm
   verify_package X11.apps.xterm
   verify_package X11.base.common
   verify_package X11.base.lib
   verify_package X11.base.rte
   verify_package X11.base.smt
   verify_package X11.base.xpconfig
   verify_package xlC.rte
   
   if [ "`uname -v`" == "5" ] && [ "`uname -r`" == "3" ]
   then
      verify_package xlC.aix50.rte
   fi
   if [ "`uname -v`" == "6" ] && [ "`uname -r`" == "1" ]
   then
      verify_package xlC.aix61.rte
   fi
}

verify_os

verify_packages

printOnScreen "RC="

case $STATUS in
   $RC_OK)
      printOnScreen "OK\n";;
   $RC_ERROR)
      printOnScreen "ERROR\n";;
   $RC_UNKNOWNOS)
      printOnScreen "UNKNOWNOS\n";;
   *)
      printOnScreen ${STATUS};;
esac

# write to the interface file for the launchpad
printOutputList
printValidOutputList

exit $STATUS
