------------------------------------------------------------------
-- Licensed Materials - Property of IBM
-- 5724-W78
-- (C) Copyright IBM Corp. 2009
-- All Rights Reserved
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
------------------------------------------------------------------

-- Connect to the database.
CONNECT TO MAXDB71
@
 
-- Removes a constraint from a table but only if the table and the constraintname exists
CREATE PROCEDURE REMOVE_CONSTRAINT (IN tablename VARCHAR(50), IN constraintname VARCHAR(50))
LANGUAGE SQL
BEGIN
	DECLARE myStmt varchar(200);
	SET myStmt = 'ALTER TABLE CLOUD.' || tablename || ' DROP CONSTRAINT ' || constraintname;
	PREPARE s1 FROM myStmt;
	
	IF EXISTS (SELECT * FROM SYSIBM.SYSTABLES WHERE NAME=tablename)
	THEN
		IF EXISTS (SELECT * FROM SYSCAT.REFERENCES WHERE CONSTNAME=constraintname)
		THEN
			EXECUTE s1;
		END IF;
	END IF;
END @

-- Removes a table if the table exists
CREATE PROCEDURE DROP_TABLE (IN tablename VARCHAR(50))
LANGUAGE SQL
BEGIN
	DECLARE tab_name varchar(50);
	SET tab_name = 'DROP TABLE CLOUD.' || tablename;
	PREPARE s1 FROM tab_name;
	IF EXISTS (SELECT * FROM SYSIBM.SYSTABLES WHERE NAME=tablename)
	THEN
		EXECUTE s1;
	END IF;
END @

-- Removes a Schema if the schema exists.
CREATE PROCEDURE DROP_SCHEMA (IN schemaname VARCHAR(50))
LANGUAGE SQL
BEGIN
	DECLARE myStmt varchar(200);
	SET myStmt = 'DROP SCHEMA ' || schemaname || ' RESTRICT';
	PREPARE s1 FROM myStmt;
	IF EXISTS (SELECT * FROM SYSIBM.SYSSCHEMATA WHERE NAME='CLOUD')
	THEN
		EXECUTE s1;
	END IF;
END @

-- Cleans up the environment before we can create the tables
CREATE PROCEDURE CLOUDDB_EXEC ()
LANGUAGE SQL
BEGIN
	IF EXISTS (SELECT * FROM SYSIBM.SYSSCHEMATA WHERE NAME='CLOUD')
	THEN
		CALL REMOVE_CONSTRAINT('PROJ_HIST', 'PR_HIST_PROJ_FK');
		CALL REMOVE_CONSTRAINT('PROJECT', 'PR_CUST_FK');
		CALL REMOVE_CONSTRAINT('CUSTOMER', 'CUST_NET_ID_UN');
		CALL REMOVE_CONSTRAINT('ROLE_PERMS', 'ROLE_PERMS_PK');
		CALL REMOVE_CONSTRAINT('CUSTOMER', 'CUSTOMER_NAME_UN');
		CALL REMOVE_CONSTRAINT('PROJ_HIST', 'PROJ_HIST_PK');
		CALL REMOVE_CONSTRAINT('CUSTOMER', 'CUSTOMER_PK');
		CALL REMOVE_CONSTRAINT('PROJECT', 'PROJECT_PK');
		CALL DROP_TABLE('CUSTOMER');
		CALL DROP_TABLE('PROJECT');
		CALL DROP_TABLE('PROJ_HIST');
		CALL DROP_TABLE('ROLE_PERMS');
		CALL DROP_SCHEMA('CLOUD');
	END IF;
END @
CALL CLOUDDB_EXEC()
@
-- Drop the Procedures afterwards, they are not longer needed here.
DROP PROCEDURE REMOVE_CONSTRAINT
@
DROP PROCEDURE CLOUDDB_EXEC
@
DROP PROCEDURE DROP_SCHEMA
@
DROP PROCEDURE DROP_TABLE
@
-- Create the tables
CREATE TABLE "CLOUD"."PROJECT" (
		"PROJECTID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH +1000  INCREMENT BY +1  MINVALUE +1000  MAXVALUE +2147483647  NO CYCLE  CACHE 20  NO ORDER),
		"NAME" VARCHAR(128) NOT NULL,
		"DESCRIPTION" VARCHAR(1024),
		"STATE" INTEGER NOT NULL,
		"STATUS" INTEGER,
		"CREATEDATE" TIMESTAMP,
		"STARTDATE" TIMESTAMP,
		"ENDDATE" TIMESTAMP,
		"SERVICESPEC" CLOB NOT NULL,
		"REQ_USER" VARCHAR(128),
		"TYPE" INTEGER DEFAULT 0 NOT NULL,
		"DEPLOY_IDS" VARCHAR(128),
		"REQ_SERVERS" INTEGER,
		"CUSTOMER_ID" INTEGER,
		"APPROVAL_STATE" INTEGER NOT NULL,
		"REQ_TIME" TIMESTAMP NOT NULL,
		"APPR_TIME" TIMESTAMP,
		"APPR_USER" VARCHAR(128),
		"ACTUAL_ENDDATE" TIMESTAMP,
		"TEMPLATE_ID" VARCHAR(128)
	)
	DATA CAPTURE NONE
@
CREATE TABLE "CLOUD"."PROJ_HIST" (
		"INDEX" INTEGER NOT NULL,
		"PROJECTID" INTEGER NOT NULL,
		"REQUESTOR" VARCHAR(64),
		"APPROVER" VARCHAR(64),
		"REQ_TIME" TIMESTAMP,
		"APPR_TIME" TIMESTAMP,
		"CHANGE_TIME" TIMESTAMP NOT NULL,
		"SERVICESPEC" CLOB NOT NULL
	)
	DATA CAPTURE NONE
@
CREATE TABLE "CLOUD"."CUSTOMER" (
		"ID" INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH +1000  INCREMENT BY +1  MINVALUE +1000  MAXVALUE +2147483647  NO CYCLE  CACHE 20  NO ORDER),
		"NAME" VARCHAR(128) NOT NULL,
		"PRIV_CUST" INTEGER,
		"ACTIVE" INTEGER,
		"NETWORK_ID" INTEGER,
		"CREATE_DATE" TIMESTAMP NOT NULL,
		"CIP_START" INTEGER,
		"CIP_END" INTEGER,
		"VPN_NAME" VARCHAR(32)
	)
	DATA CAPTURE NONE
@
CREATE TABLE "CLOUD"."ROLE_PERMS" (
		"ROLE_NAME" VARCHAR(64) NOT NULL,
		"PERM_CODE" INTEGER NOT NULL,
		"CUST_ONLY" INTEGER DEFAULT 0
	)
	DATA CAPTURE NONE
@
ALTER TABLE "CLOUD"."PROJECT" ADD CONSTRAINT "PROJECT_PK" PRIMARY KEY ("PROJECTID")
@
ALTER TABLE "CLOUD"."PROJ_HIST" ADD CONSTRAINT "PROJ_HIST_PK" PRIMARY KEY ("PROJECTID", "INDEX")
@
ALTER TABLE "CLOUD"."CUSTOMER" ADD CONSTRAINT "CUSTOMER_PK" PRIMARY KEY ("ID")
@
ALTER TABLE "CLOUD"."CUSTOMER" ADD CONSTRAINT "CUSTOMER_NAME_UN" UNIQUE ("NAME")
@
ALTER TABLE "CLOUD"."ROLE_PERMS" ADD CONSTRAINT "ROLE_PERMS_PK" PRIMARY KEY ("ROLE_NAME", "PERM_CODE")
@
ALTER TABLE "CLOUD"."PROJECT" ADD CONSTRAINT "PR_CUST_FK" FOREIGN KEY ("CUSTOMER_ID")
	REFERENCES "CLOUD"."CUSTOMER" ("ID")
	ON DELETE RESTRICT
@
ALTER TABLE "CLOUD"."PROJ_HIST" ADD CONSTRAINT "PR_HIST_PROJ_FK" FOREIGN KEY ("PROJECTID")
	REFERENCES "CLOUD"."PROJECT" ("PROJECTID")
	ON DELETE CASCADE
@
COMMENT ON TABLE "CLOUD"."CUSTOMER" IS
'Column TBC'
@
COMMENT ON COLUMN "CLOUD"."PROJ_HIST"."REQUESTOR" IS
'If null => change was detected out of band and not requested/approved'
@
COMMENT ON COLUMN "CLOUD"."ROLE_PERMS"."CUST_ONLY" IS
'Boolean'
@