<?xml version="1.0" encoding="UTF-8"?>
<!--
 ******************************************************************
 * Licensed Materials - Property of IBM
 * 5724-W78
 * (C) Copyright IBM Corp. 2010
 * All Rights Reserved
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ******************************************************************
-->
<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
<!--                                                                            -->
<!-- Transform a TSAM SR,TICKETSPEC object structure into XML that is           -->
<!-- compatible with Create Project.                                            -->
<!--                                                                            -->
<!-- Make sure the Maximo namespace is added                                    -->
<!--                                                                            -->
<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
<xsl:stylesheet xmlns="http://www.ibm.com/hipods/cloud-project" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.1" xmlns:out="http://www.ibm.com/hipods/ui-answers" >
	<xsl:output method="xml" indent="yes"/>
	<xsl:template match="//PMRDPVSRPARM" name="params">
		<params>
			<xsl:for-each select="//PMRDPVSRPARM[./SRCTOKEN != 'PMRDPVSRPARM_SOFTWARENAME']">
				<param>
					<name>
						<xsl:value-of select="SRCATTRNAME"/>
					</name>
					<value>						
						<xsl:value-of select="SRCATTRVAL"/>
					</value>
					<type>
						<xsl:value-of select="SRCTYPE"/>
					</type>
				</param>
			</xsl:for-each>
		</params>
	</xsl:template>
	<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
	<!--                                                                            -->
	<!-- Match anything                                                             -->
	<!--                                                                            -->
	<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
	<xsl:template match="/">
		<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
		<!--                                                                            -->
		<!-- This assumes everything we need will come from the TICKETSPEC section of   -->
		<!-- an object structure that includes the SR and TICKETSPEC.                   -->
		<!--                                                                            -->
		<!-- N.B. This assumes the output is not order dependent.                       -->
		<!--      This does add the monitoring software at the end                      -->
		<!--      of the software installables.                                         -->
		<!--                                                                            -->
		<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
		<project>
			<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
			<!--                                                                            -->
			<!-- Find the project name. We assume it is always there.                       -->
			<!--                                                                            -->
			<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
			<name>
				<xsl:value-of select="//TICKETSPEC[./ASSETATTRID='PMRDPCLCPR_PROJECTNAME']/ALNVALUE"/>
			</name>
			<cart>
				<entry>
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<!--                                                                            -->
					<!-- Find the Ticket ID. We assume it is always there.  We add it to custom     -->
					<!-- params. Even though this occurs once, instead of putting at the project    -->
					<!-- level, like it is described in the spec, we'll replicate it for every      -->
					<!-- server.  Someone wants it that way...                                      -->
					<!--                                                                            -->
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<params>
						<param>
							<name>ticketId</name>
							<value>
								<xsl:value-of select="//SR/TICKETID"/>
							</value>
						</param>
					</params>
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<!--                                                                            -->
					<!-- Use a default name for what will be a TPM cluster name                     -->
					<!--                                                                            -->
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<!-- <name>server</name>  now will also use ticketId for the tpm cluster name -->
					<name>
						<xsl:value-of select="//SR/TICKETID"/>
					</name>
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<!--                                                                            -->
					<!-- Remove any decimal point and beyond in any NUMVALUE.                       -->
					<!-- Either floor() or substring-before(./NUMVALUE,'.') works.              -->
					<!-- Or remove floor() to get the raw value, if desired.                        -->
					<!--                                                                            -->
					<!-- We expect the following to always be there...                              -->
					<!--                                                                            -->
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<count>
						<xsl:value-of select="floor(//TICKETSPEC[./ASSETATTRID='PMRDPCLCPR_SERVERQTY']/NUMVALUE)"/>
					</count>
					<pooluri>
						<xsl:value-of select="//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_RESGRPNUM']/ALNVALUE"/>
					</pooluri>
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<!--                                                                            -->
					<!-- The following may not be there, so test them since we are using            -->
					<!-- floor() - it will output NaN if the input is null.                         -->
					<!--                                                                            -->
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<xsl:if test="normalize-space(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_MEMORY']/NUMVALUE)">
						<ram>
							<xsl:value-of select="floor(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_MEMORY']/NUMVALUE)"/>
						</ram>
					</xsl:if>
					<xsl:if test="normalize-space(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_STORAGE_SIZE']/NUMVALUE)">
						<disk>
							<xsl:value-of select="floor(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_STORAGE_SIZE']/NUMVALUE)"/>
						</disk>
					</xsl:if>
					<xsl:if test="normalize-space(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_SWAP_SIZE']/NUMVALUE)">
						<swap>
							<xsl:value-of select="//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_SWAP_SIZE']/NUMVALUE"/>
						</swap>
					</xsl:if>
					<xsl:if test="normalize-space(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_NUMBER_CPUS']/NUMVALUE)">
						<cpus>
							<xsl:value-of select="floor(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_NUMBER_CPUS']/NUMVALUE)"/>
						</cpus>
					</xsl:if>
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<!--                                                                            -->
					<!-- The following may not be there, so test them.  These we'll use the real    -->
					<!-- value for, i.e. no floor function.                                         -->
					<!--                                                                            -->
					<!-- Value from SR will be tenths of pcpu unit, hence divide by 10 here         -->
					<!--                                                                            -->
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<xsl:if test="normalize-space(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_NUMBER_PCPUS']/NUMVALUE)">
						<pcpu>
							<xsl:value-of select="(//TICKETSPEC[./ASSETATTRID='PMRDPCLCVS_NUMBER_PCPUS']/NUMVALUE) div 10.0"/>
						</pcpu>
					</xsl:if>
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<!--                                                                            -->
					<!-- Use the SW Image, making sure it is first.  We assume it is always there.  -->
					<!--                                                                            -->
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<imageid>
						<xsl:value-of select="floor(//TICKETSPEC[./ASSETATTRID='PMRDPCLSWS_IMAGEID']/NUMVALUE)"/>
					</imageid>
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<!--                                                                            -->
					<!-- Process software.  This element will appear only once.                     -->
					<!--                                                                            -->
					<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
					<software>
						<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
						<!--                                                                            -->
						<!-- Look for software specified in the TICKETSPEC.                             -->
						<!-- Create anything found as an <installable>.                                 -->
						<!--                                                                            -->
						<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
						<xsl:for-each select="//TICKETSPEC">
							<xsl:choose>
								<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
								<!--                                                                            -->
								<!-- Right now we do not support a SW stack name.                               -->
								<!-- We look for the prefix PMRDPCLCPR_SOFTWARENAME.                            -->
								<!--                                                                            -->
								<!-- Other examples:                                                            -->
								<!--                                                                            -->
								<!-- xsl:when test="./ASSETATTRID='PMRDPCLCSWS_SWSTACKID'"                  -->
								<!-- xsl:when test="substring(./ASSETATTRID,1,22)='PMRDPCLCPR_SOFTWARENAM'" -->
								<!--                                                                            -->
								<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
								<xsl:when test="starts-with(./ASSETATTRID,'PMRDPCLCPR_SOFTWARENAME')">
									<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
									<!--                                                                            -->
									<!-- Just in case the receptor of this output cannot handle an empty            -->
									<!-- installable, we'll write one only if the value is filled in.               -->
									<!--                                                                            -->
									<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
									<xsl:choose>
										<xsl:when test="./ALNVALUE!=''">
											<installable>
												<xsl:value-of select="./ALNVALUE"/>
											</installable>
										</xsl:when>
									</xsl:choose>
								</xsl:when>
							</xsl:choose>
						</xsl:for-each>
						<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
						<!--                                                                            -->
						<!-- See if monitoring software is needed.                                      -->
						<!--                                                                            -->
						<!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  -->
						<xsl:variable name="monitor">
							<xsl:value-of select="//TICKETSPEC[./ASSETATTRID='PMRDPCLSWS_MONITORING']/ALNVALUE"/>
						</xsl:variable>
						<xsl:if test="$monitor = 'on'">
							<installable>IBM Tivoli Monitoring Agent</installable>
						</xsl:if>
						<!--
							Check for PMRDPVSRPARM defining software
						-->
						<xsl:for-each
							select="//PMRDPVSRPARM[./SRCTOKEN = 'PMRDPVSRPARM_SOFTWARENAME' and ./SRCATTRNAME = 'position']">
							<xsl:variable name="SOFTWARE_NAME" select="./SRCNAME" />
							<installable>
								<name>
									<xsl:value-of select="$SOFTWARE_NAME" />
								</name>
								<params>
									<xsl:for-each
										select="//PMRDPVSRPARM[./SRCNAME = $SOFTWARE_NAME]">

										<param>
											<name>
												<xsl:value-of select="SRCATTRNAME" />
											</name>
											<value>
												<xsl:value-of select="SRCATTRVAL" />
											</value>
										</param>
									</xsl:for-each>
								</params>
							</installable>
						</xsl:for-each>

						<!--
							End check for PMRDPVSRPARM defining software
						-->
					</software>
					<xsl:variable name="customparams">
						<xsl:value-of select="//TICKETSPEC[./ASSETATTRID='CustomParamID']/ALNVALUE"/>
					</xsl:variable>
					<xsl:if test="$customparams = '1'">
						<params>IBM Tivoli Monitoring Agent</params>
					</xsl:if>
					<xsl:call-template name="params"/>
				</entry>
			</cart>
		</project>
	</xsl:template>
</xsl:stylesheet>
